@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIsolatedWatershedImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2004-05-20 00:03:01 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,7 +22,8 @@
 #include "itkWatershedImageFilter.h"
 #include "itkGradientMagnitudeImageFilter.h"
 
-namespace itk{
+namespace itk
+{
 
 /** /class IsolatedWatershedImageFilter
  * \brief Isolate watershed basins using two seeds
@@ -43,10 +44,10 @@ class ITK_EXPORT IsolatedWatershedImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef IsolatedWatershedImageFilter Self;
+  typedef IsolatedWatershedImageFilter                 Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -55,20 +56,20 @@ public:
   itkTypeMacro(IsolatedWatershedImageFilter,
                ImageToImageFilter);
 
-  typedef TInputImage InputImageType;
-  typedef typename InputImageType::Pointer InputImagePointer;
+  typedef TInputImage                           InputImageType;
+  typedef typename InputImageType::Pointer      InputImagePointer;
   typedef typename InputImageType::ConstPointer InputImageConstPointer;
-  typedef typename InputImageType::RegionType InputImageRegionType; 
-  typedef typename InputImageType::PixelType InputImagePixelType; 
-  typedef typename InputImageType::IndexType IndexType;
-  typedef typename InputImageType::SizeType SizeType;
+  typedef typename InputImageType::RegionType   InputImageRegionType; 
+  typedef typename InputImageType::PixelType    InputImagePixelType; 
+  typedef typename InputImageType::IndexType    IndexType;
+  typedef typename InputImageType::SizeType     SizeType;
   
-  typedef TOutputImage OutputImageType;
-  typedef typename OutputImageType::Pointer OutputImagePointer;
+  typedef TOutputImage                         OutputImageType;
+  typedef typename OutputImageType::Pointer    OutputImagePointer;
   typedef typename OutputImageType::RegionType OutputImageRegionType; 
-  typedef typename OutputImageType::PixelType OutputImagePixelType; 
+  typedef typename OutputImageType::PixelType  OutputImagePixelType; 
   
-  typedef WatershedImageFilter<InputImageType> WatershedType;
+  typedef WatershedImageFilter<InputImageType>                         WatershedType;
   typedef GradientMagnitudeImageFilter<InputImageType,OutputImageType> GradientMagnitudeType;
   void PrintSelf ( std::ostream& os, Indent indent ) const;
 
@@ -84,40 +85,40 @@ public:
 
   /** Set/Get the Watershed threshold. The default is 0. */
   itkSetMacro(Threshold, double);
-  itkGetMacro(Threshold, double);
+  itkGetConstMacro(Threshold, double);
 
   /** Set/Get the precision required for the intensity threshold
    *  value. The default is .001. */
   itkSetMacro(IsolatedValueTolerance, double);
-  itkGetMacro(IsolatedValueTolerance, double);
+  itkGetConstMacro(IsolatedValueTolerance, double);
 
   /** Set/Get the limit on the upper waterlevel value. The default is
    *  1.0. */
   itkSetMacro(UpperValueLimit, double);
-  itkGetMacro(UpperValueLimit, double);
+  itkGetConstMacro(UpperValueLimit, double);
 
 
   /** Set/Get value to replace Seed1(Seed2) pixels, pixels that are
    *  within the basin that contains Seed1(Seed2) this  value. The
    *  default is 1(0). */
   itkSetMacro(ReplaceValue1, OutputImagePixelType);
-  itkGetMacro(ReplaceValue1, OutputImagePixelType);
+  itkGetConstMacro(ReplaceValue1, OutputImagePixelType);
   itkSetMacro(ReplaceValue2, OutputImagePixelType);
-  itkGetMacro(ReplaceValue2, OutputImagePixelType);
+  itkGetConstMacro(ReplaceValue2, OutputImagePixelType);
 
   /** Get value that isolates the two seeds. */
-  itkGetMacro(IsolatedValue, double);
+  itkGetConstMacro(IsolatedValue, double);
 
 protected:
   IsolatedWatershedImageFilter();
   ~IsolatedWatershedImageFilter(){};
-  IndexType m_Seed1;
-  IndexType m_Seed2;
+  IndexType            m_Seed1;
+  IndexType            m_Seed2;
   OutputImagePixelType m_ReplaceValue1;
   OutputImagePixelType m_ReplaceValue2;
 
   typename GradientMagnitudeType::Pointer m_GradientMagnitude;
-  typename WatershedType::Pointer m_Watershed;
+  typename WatershedType::Pointer         m_Watershed;
 
   double m_Threshold;
   double m_IsolatedValue;
