@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIsotropicFourthOrderLevelSetImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:33 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
      =========================================================================*/
-#ifndef _itkIsotropicFourthOrderLevelSetImageFilter_h_
-#define _itkIsotropicFourthOrderLevelSetImageFilter_h_
+#ifndef __itkIsotropicFourthOrderLevelSetImageFilter_h
+#define __itkIsotropicFourthOrderLevelSetImageFilter_h
 
 #include "itkLevelSetFunctionWithRefitTerm.h"
 #include "itkSparseFieldFourthOrderLevelSetImageFilter.h"
@@ -76,10 +76,10 @@ class ITK_EXPORT IsotropicFourthOrderLevelSetImageFilter
 public:
   /** Standard class typedefs */
   typedef IsotropicFourthOrderLevelSetImageFilter Self;
-  typedef SparseFieldFourthOrderLevelSetImageFilter <TInputImage,
-                                                     TOutputImage> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SparseFieldFourthOrderLevelSetImageFilter <TInputImage,TOutputImage>
+                                                  Superclass;
+  typedef SmartPointer<Self>                      Pointer;
+  typedef SmartPointer<const Self>                ConstPointer;
 
   /** Run-time type information (and related methods) */
   itkTypeMacro(IsotropicFourthOrderLevelSetImageFilter,
@@ -98,7 +98,7 @@ public:
   /** The radius type for the neighborhoods. */
   typedef typename FunctionType::RadiusType RadiusType;
 
-  itkGetMacro(MaxFilterIteration,unsigned int);
+  itkGetConstMacro(MaxFilterIteration,unsigned int);
   itkSetMacro(MaxFilterIteration,unsigned int);
   
 protected:
@@ -114,10 +114,10 @@ protected:
 
   /** This filter halts when the iteration count reaches the specified count. */
   virtual bool Halt()
-  {
-    if (this->GetElapsedIterations()==m_MaxFilterIteration) return true;
+    {
+    if (this->GetElapsedIterations() == m_MaxFilterIteration) return true;
     else return false;
-  }
+    }
 
 private:
   IsotropicFourthOrderLevelSetImageFilter(const Self&);
