@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMutualInformationHistogramImageToImageMetric.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:35 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-05-02 05:43:55 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,24 +21,23 @@
 
 namespace itk
 {
-  /** \class MutualInformationHistogramImageToImageMetric
-      \brief Computes the mutual information between two images to
-      be registered using the histograms of the intensities in the images.
-
-      This class is templated over the type of the fixed and moving
-      images to be compared.
-
-      This metric computes the similarity measure between pixels in the
-      moving image and pixels in the fixed images using a histogram.
-
-      \ingroup RegistrationMetrics */
+/** \class MutualInformationHistogramImageToImageMetric
+ * \brief Computes the mutual information between two images to be
+ * registered using the histograms of the intensities in the images.
+ * This class is templated over the type of the fixed and moving
+ * images to be compared.
+ *
+ * This metric computes the similarity measure between pixels in the
+ * moving image and pixels in the fixed images using a histogram.
+ *
+ * \ingroup RegistrationMetrics */
 template <class TFixedImage, class TMovingImage>
 class ITK_EXPORT MutualInformationHistogramImageToImageMetric :
 public HistogramImageToImageMetric<TFixedImage, TMovingImage>
 {
- public:
+public:
   /** Standard class typedefs. */
-  typedef MutualInformationHistogramImageToImageMetric Self;
+  typedef MutualInformationHistogramImageToImageMetric           Self;
   typedef HistogramImageToImageMetric<TFixedImage, TMovingImage> Superclass;
   typedef SmartPointer<Self>                                     Pointer;
   typedef SmartPointer<const Self>                               ConstPointer;
@@ -68,7 +67,11 @@ public HistogramImageToImageMetric<TFixedImage, TMovingImage>
     MovingImageConstPointer;
 
   typedef typename Superclass::HistogramType            HistogramType;
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef typename HistogramType::AbsoluteFrequencyType HistogramFrequencyType;
+#else
   typedef typename HistogramType::FrequencyType         HistogramFrequencyType;
+#endif
   typedef typename HistogramType::Iterator              HistogramIteratorType;
   typedef typename HistogramType::MeasurementVectorType
     HistogramMeasurementVectorType;
