@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRGBGibbsPriorFilter.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:37 $
-  Version:   $Revision: 1.29 $
+  Date:      $Date: 2009-04-23 03:53:36 $
+  Version:   $Revision: 1.31 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -48,15 +48,11 @@ class ITK_EXPORT RGBGibbsPriorFilter : public MRFImageFilter<TInputImage,
                                                              TClassifiedImage>
 {
 public:
-  /** Standard "Self" typedef.*/
-  typedef RGBGibbsPriorFilter  Self;
-
-  /** Standard "Superclass" typedef.*/
+  /** Standard "Self" typedef. */
+  typedef RGBGibbsPriorFilter                           Self;
   typedef MRFImageFilter<TInputImage, TClassifiedImage> Superclass;
-
-  /** Smart pointer typedef support */
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -65,12 +61,12 @@ public:
   itkTypeMacro(RGBGibbsPriorFilter,MRFImageFilter);
 
   /** Types from superclass.  */
-  typedef typename Superclass::InputImagePixelType InputImagePixelType;
+  typedef typename Superclass::InputImagePixelType           InputImagePixelType;
   typedef typename Superclass::InputImageRegionConstIterator InputImageRegionConstIterator;
-  typedef typename Superclass::InputImageRegionIterator InputImageRegionIterator;
-  typedef typename Superclass::LabelledImageRegionIterator LabelledImageRegionIterator;
-  typedef typename Superclass::LabelledImagePixelType LabelledImagePixelType;
-  typedef typename Superclass::IndexValueType IndexValueType;
+  typedef typename Superclass::InputImageRegionIterator      InputImageRegionIterator;
+  typedef typename Superclass::LabelledImageRegionIterator   LabelledImageRegionIterator;
+  typedef typename Superclass::LabelledImagePixelType        LabelledImagePixelType;
+  typedef typename Superclass::IndexValueType                IndexValueType;
   
   /** A smart pointer to the input image type. */
   typedef TInputImage                                InputImageType;  
@@ -84,7 +80,7 @@ public:
   typedef typename TClassifiedImage::Pointer         TrainingImageType;
 
   /** Type definitions for the labelled image.
-   *  It is derived from the training image.*/
+   *  It is derived from the training image. */
   typedef typename TClassifiedImage::Pointer         LabelledImageType;
      
   /** Type definition for the classified image index type. */
@@ -105,12 +101,12 @@ public:
   /** Set the image required for training type classifiers. */
   void SetTrainingImage(TrainingImageType image);
 
-  /** Set the labelled image.*/
+  /** Set the labelled image. */
   void SetLabelledImage(LabelledImageType LabelledImage);
 
   /** Get the labelled image. */
   LabelledImageType GetLabelledImage()
-  { return m_LabelledImage; }
+    { return m_LabelledImage; }
 
   /** Set the pointer to the classifer being used. */
   void SetClassifier( typename ClassifierType::Pointer ptrToClassifier );
@@ -119,15 +115,15 @@ public:
   itkSetMacro(NumberOfClasses, unsigned int);
 
   /** Get the Number of classes. */
-  itkGetMacro(NumberOfClasses, unsigned int);
+  itkGetConstMacro(NumberOfClasses, unsigned int);
 
   /** Set/Get the number of iteration of the Iterated Conditional Mode
    * (ICM) algorithm. A default value is set at 50 iterations. */
   itkSetMacro(MaximumNumberOfIterations, unsigned int);
 
   /** Get the number of iterations of the Iterated Conditional Mode
-   * (ICM) algorithm.*/
-  itkGetMacro(MaximumNumberOfIterations, unsigned int);
+   * (ICM) algorithm. */
+  itkGetConstMacro(MaximumNumberOfIterations, unsigned int);
 
   /** Set the threshold for the object size. */
   itkSetMacro(ClusterSize, unsigned int);
@@ -147,17 +143,17 @@ public:
 
   /** set and get the value for Clique weights */
   itkSetMacro(CliqueWeight_1, double);
-  itkGetMacro(CliqueWeight_1, double);
+  itkGetConstMacro(CliqueWeight_1, double);
   itkSetMacro(CliqueWeight_2, double);
-  itkGetMacro(CliqueWeight_2, double);
+  itkGetConstMacro(CliqueWeight_2, double);
   itkSetMacro(CliqueWeight_3, double);
-  itkGetMacro(CliqueWeight_3, double);
+  itkGetConstMacro(CliqueWeight_3, double);
   itkSetMacro(CliqueWeight_4, double);
-  itkGetMacro(CliqueWeight_4, double);
+  itkGetConstMacro(CliqueWeight_4, double);
   itkSetMacro(CliqueWeight_5, double);
-  itkGetMacro(CliqueWeight_5, double);
+  itkGetConstMacro(CliqueWeight_5, double);
   itkSetMacro(CliqueWeight_6, double);
-  itkGetMacro(CliqueWeight_6, double);
+  itkGetConstMacro(CliqueWeight_6, double);
 
 
   /** Specify the type of matrix to use. */
@@ -185,9 +181,11 @@ private:
   InputImageConstPointer  m_InputImage;    /** the input */
   TrainingImageType       m_TrainingImage; /** image to train the filter. */
   LabelledImageType       m_LabelledImage; /** output */
-  unsigned int        m_NumberOfClasses; /** the number of class need to be classified. */
-  unsigned int        m_MaximumNumberOfIterations; /** number of the iteration. */
+  unsigned int            m_NumberOfClasses; /** the number of class need to be classified. */
+  unsigned int            m_MaximumNumberOfIterations; /** number of the iteration. */
+
   typename ClassifierType::Pointer m_ClassifierPtr;
+
   unsigned int      m_BoundaryGradient; /** the threshold for the existence of a boundary. */
   double            m_BoundaryWeight; /** weight for H_1 */
   double            m_GibbsPriorWeight; /** weight for H_2 */
@@ -197,8 +195,8 @@ private:
 
   InputImagePointer  m_MediumImage;   /** the medium image to store intermedium result */
 
-  unsigned int      m_Temp;         /** for SA algo. */
-  IndexType m_StartPoint; /** the seed of object */
+  unsigned int      m_Temp;       /** for SA algo. */
+  IndexType         m_StartPoint; /** the seed of object */
 
   unsigned int      m_ImageWidth; /** image size. */
   unsigned int      m_ImageHeight;
