@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkWatershedMiniPipelineProgressCommand.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:41 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-05-12 20:21:46 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -47,14 +47,11 @@ void WatershedMiniPipelineProgressCommand
     }
 }
 
-
-
-
-
-
-
-
-
-
+void WatershedMiniPipelineProgressCommand
+::PrintSelf(std::ostream& os, Indent indent) const
+{
+  Superclass::PrintSelf(os,indent);
+  os << indent << "NumberOfFilters: " << m_NumberOfFilters << std::endl;
+  os << indent << "Count: " << m_Count << std::endl;
+}
 } // end namespace itk
-
