@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBoundedReciprocalImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:40 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-01 14:36:10 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -42,17 +42,17 @@ public:
   BoundedReciprocal() {};
   ~BoundedReciprocal() {};
   bool operator!=( const BoundedReciprocal & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const BoundedReciprocal & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
     return static_cast<TOutput>( 1.0 / ( 1.0 +  static_cast<double>(A) ) );
-  }
+    }
 };
 }
 
@@ -71,9 +71,9 @@ public:
                                   Functor::BoundedReciprocal< 
     typename TInputImage::PixelType, 
     typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  >                                     Superclass;
+  typedef SmartPointer<Self>            Pointer;
+  typedef SmartPointer<const Self>      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
