@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDiscreteGaussianImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-27 17:01:06 $
-  Version:   $Revision: 1.39 $
+  Date:      $Date: 2009-04-25 12:27:21 $
+  Version:   $Revision: 1.41 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -58,10 +58,10 @@ class ITK_EXPORT DiscreteGaussianImageFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef DiscreteGaussianImageFilter Self;
+  typedef DiscreteGaussianImageFilter                     Self;
   typedef ImageToImageFilter< TInputImage, TOutputImage > Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                              Pointer;
+  typedef SmartPointer<const Self>                        ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -75,10 +75,10 @@ public:
 
   /** Extract some information from the image types.  Dimensionality
    * of the two images is assumed to be the same. */
-  typedef typename TOutputImage::PixelType OutputPixelType;
+  typedef typename TOutputImage::PixelType         OutputPixelType;
   typedef typename TOutputImage::InternalPixelType OutputInternalPixelType;
-  typedef typename TInputImage::PixelType InputPixelType;
-  typedef typename TInputImage::InternalPixelType InputInternalPixelType;
+  typedef typename TInputImage::PixelType          InputPixelType;
+  typedef typename TInputImage::InternalPixelType  InputInternalPixelType;
 
   /** Extract some information from the image types.  Dimensionality
    * of the two images is assumed to be the same. */
@@ -92,19 +92,20 @@ public:
    * independently for each dimension, but 
    * see also SetVariance(const double v). The default is 0.0 in each
    * dimension. If UseImageSpacing is true, the units are the physical units
-   * of your image.  If UseImageSpacing is false then the units are pixels.*/
+   * of your image.  If UseImageSpacing is false then the units are
+   * pixels. */
   itkSetMacro(Variance, ArrayType);
-  itkGetMacro(Variance, const ArrayType);
+  itkGetConstMacro(Variance, const ArrayType);
 
   /** The algorithm will size the discrete kernel so that the error
    * resulting from truncation of the kernel is no greater than
    * MaximumError. The default is 0.01 in each dimension. */
   itkSetMacro(MaximumError, ArrayType);
-  itkGetMacro(MaximumError, const ArrayType);
+  itkGetConstMacro(MaximumError, const ArrayType);
 
   /** Set the kernel to be no wider than MaximumKernelWidth pixels,
    *  even if MaximumError demands it. The default is 32 pixels. */
-  itkGetMacro(MaximumKernelWidth, int);
+  itkGetConstMacro(MaximumKernelWidth, int);
   itkSetMacro(MaximumKernelWidth, int);
 
   /** Set the number of dimensions to smooth. Defaults to the image
@@ -112,76 +113,76 @@ public:
    * the dimensions less than FilterDimensionality.  For instance, to
    * smooth the slices of a volume without smoothing in Z, set the
    * FilterDimensionality to 2. */
-  itkGetMacro(FilterDimensionality, unsigned int);
+  itkGetConstMacro(FilterDimensionality, unsigned int);
   itkSetMacro(FilterDimensionality, unsigned int);
   
   /** Convenience Set methods for setting all dimensional parameters
    *  to the same values. */
   void SetVariance (const typename ArrayType::ValueType v)
     {
-      m_Variance.Fill(v);
+    m_Variance.Fill(v);
     }
 
   void SetMaximumError (const typename ArrayType::ValueType v)
     {
-      m_MaximumError.Fill(v);
+    m_MaximumError.Fill(v);
     }
 
   void SetVariance (const double *v)
     {
-      ArrayType dv;
-      for (unsigned int i = 0; i < ImageDimension; i++)
-        {
-        dv[i] = v[i];
-        }
-      this->SetVariance(dv);
+    ArrayType dv;
+    for (unsigned int i = 0; i < ImageDimension; i++)
+      {
+      dv[i] = v[i];
+      }
+    this->SetVariance(dv);
     }
 
   void SetVariance (const float *v)
     {
-      ArrayType dv;
-      for (unsigned int i = 0; i < ImageDimension; i++)
-        {
-        dv[i] = v[i];
-        }
-      this->SetVariance(dv);
+    ArrayType dv;
+    for (unsigned int i = 0; i < ImageDimension; i++)
+      {
+      dv[i] = v[i];
+      }
+    this->SetVariance(dv);
     }
 
   void SetMaximumError (const double *v)
     {
-      ArrayType dv;
-      for (unsigned int i = 0; i < ImageDimension; i++)
-        {
-        dv[i] = v[i];
-        }
-      this->SetMaximumError(dv);
+    ArrayType dv;
+    for (unsigned int i = 0; i < ImageDimension; i++)
+      {
+      dv[i] = v[i];
+      }
+    this->SetMaximumError(dv);
     }
 
   void SetMaximumError (const float *v)
     {
-      ArrayType dv;
-      for (unsigned int i = 0; i < ImageDimension; i++)
-        {
-        dv[i] = v[i];
-        }
-      this->SetMaximumError(dv);
+    ArrayType dv;
+    for (unsigned int i = 0; i < ImageDimension; i++)
+      {
+      dv[i] = v[i];
+      }
+    this->SetMaximumError(dv);
     }
 
   /** Use the image spacing information in calculations. Use this option if you
    *  want to specify Gaussian variance in real world units.  Default is
    *   ImageSpacingOn. */
   void SetUseImageSpacingOn()
-  { this->SetUseImageSpacing(true); }
+    { this->SetUseImageSpacing(true); }
   
   /** Ignore the image spacing. Use this option if you want to specify Gaussian
       variance in pixels.  Default is ImageSpacingOn. */
   void SetUseImageSpacingOff()
-  { this->SetUseImageSpacing(false); }
+    { this->SetUseImageSpacing(false); }
   
   /** Set/Get whether or not the filter will use the spacing of the input
       image in its calculations */
   itkSetMacro(UseImageSpacing, bool);
-  itkGetMacro(UseImageSpacing, bool);
+  itkGetConstMacro(UseImageSpacing, bool);
   
   /** DiscreteGaussianImageFilter needs a larger input requested region
    * than the output requested region (larger by the size of the
@@ -200,13 +201,13 @@ public:
 
 protected:
   DiscreteGaussianImageFilter()
-  {
+    {
     m_Variance.Fill(0.0);
     m_MaximumError.Fill(0.01);
     m_MaximumKernelWidth = 32;
     m_UseImageSpacing = true;
     m_FilterDimensionality = ImageDimension;
-  }
+    }
   virtual ~DiscreteGaussianImageFilter() {}
   void PrintSelf(std::ostream& os, Indent indent) const;
 
