@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGrayscaleGrindPeakImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-16 14:22:34 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-10-16 16:45:09 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,8 +17,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkGrindPeakImageFilter_h
-#define __itkGrindPeakImageFilter_h
+#ifndef __itkGrayscaleGrindPeakImageFilter_h
+#define __itkGrayscaleGrindPeakImageFilter_h
 
 #include "itkImageToImageFilter.h"
 
@@ -65,17 +65,17 @@ public:
   /** Standard class typedefs. */
   typedef GrayscaleGrindPeakImageFilter Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>
-    Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+                                        Superclass;
+  typedef SmartPointer<Self>            Pointer;
+  typedef SmartPointer<const Self>      ConstPointer;
 
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                              InputImageType;
   typedef typename InputImageType::Pointer         InputImagePointer;
   typedef typename InputImageType::ConstPointer    InputImageConstPointer;
   typedef typename InputImageType::RegionType      InputImageRegionType;
   typedef typename InputImageType::PixelType       InputImagePixelType;
+  typedef TOutputImage                             OutputImageType;
   typedef typename OutputImageType::Pointer        OutputImagePointer;
   typedef typename OutputImageType::ConstPointer   OutputImageConstPointer;
   typedef typename OutputImageType::RegionType     OutputImageRegionType;
@@ -129,7 +129,7 @@ protected:
   /** GrayscaleGrindPeakImageFilter needs the entire input be
    * available. Thus, it needs to provide an implementation of
    * GenerateInputRequestedRegion(). */
-  void GenerateInputRequestedRegion() ;
+  void GenerateInputRequestedRegion();
 
   /** GrayscaleGrindPeakImageFilter will produce the entire output. */
   void EnlargeOutputRequestedRegion(DataObject *itkNotUsed(output));
@@ -146,7 +146,7 @@ private:
   unsigned long m_NumberOfIterationsUsed;
 
   bool                m_FullyConnected;
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
@@ -155,5 +155,3 @@ private:
 #endif
 
 #endif
-
-
