@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkScalarConnectedComponentImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-09-26 12:05:05 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-07-05 17:36:22 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -42,27 +42,53 @@ class SimilarPixelsFunctor
 {
 public:
   SimilarPixelsFunctor()
-    {m_Threshold = itk::NumericTraits<TInput>::Zero;};
-  ~SimilarPixelsFunctor() {};
-  bool operator!=( const SimilarPixelsFunctor & other ) const
-  {
-    if( m_Threshold != other.m_Threshold )
-        {
-        return true;
-        }
-    return false;
-   }
-  bool operator==( const SimilarPixelsFunctor & other ) const
-  {
-    return !(*this != other);
-  }
+    {
+    m_Threshold = NumericTraits<TInput>::Zero;
+    }
 
-  void SetDistanceThreshold(const TInput &thresh) {m_Threshold = thresh;};
-  TInput GetDistanceThreshold() {return (m_Threshold);};
+  ~SimilarPixelsFunctor() 
+    {
+    }
+
+  bool operator!=( const SimilarPixelsFunctor & other ) const
+    {
+    if( m_Threshold != other.m_Threshold )
+      {
+      return true;
+      }
+    return false;
+    }
+
+  bool operator==( const SimilarPixelsFunctor & other ) const
+    {
+    return !(*this != other);
+    }
+
+  void SetDistanceThreshold(const TInput &thresh) 
+    {
+    m_Threshold = thresh;
+    }
+
+  TInput GetDistanceThreshold() 
+    {
+    return (m_Threshold);
+    }
   
-  bool operator()(const TInput &a, const TInput &b) {
-    return (vnl_math_abs(a-b) <= m_Threshold);
-  };
+  bool operator()(const TInput &a, const TInput &b) const
+    {
+    typedef typename NumericTraits<TInput>::RealType InputRealType;
+    TInput absDifference = static_cast<TInput>( vnl_math_abs( 
+                           static_cast<InputRealType>(a)
+                           - static_cast<InputRealType>(b) ) );
+    if( absDifference <= m_Threshold )
+      {
+      return true;
+      }
+    else
+      {
+      return false;
+      }
+    }
 
 protected:
   TInput m_Threshold;
@@ -80,11 +106,12 @@ class ITK_EXPORT ScalarConnectedComponentImageFilter :
 public:
   /** Standard class typedefs. */
   typedef ScalarConnectedComponentImageFilter Self;
-  typedef ConnectedComponentFunctorImageFilter<TInputImage,TOutputImage, 
-             Functor::SimilarPixelsFunctor<typename TInputImage::ValueType>,
-             TMaskImage> Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef ConnectedComponentFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::SimilarPixelsFunctor<typename TInputImage::ValueType>,
+    TMaskImage>                               Superclass;
+  typedef SmartPointer<Self>                  Pointer;
+  typedef SmartPointer<const Self>            ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
