@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCenteredEuler3DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:07 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-09 09:23:20 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -77,6 +77,11 @@ public:
   typedef typename Superclass::TranslationType            TranslationType;
   typedef typename Superclass::OffsetType                 OffsetType;
 
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost.*/
+  typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
+  typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
+
   /** Set the transformation from a container of parameters
    * This is typically used by optimizers.
    * There are six parameters. The first three represent the
@@ -95,6 +100,12 @@ public:
    * transform is invertible at this point. */
   const JacobianType & GetJacobian(const InputPointType  &point ) const;
 
+  /** Get an inverse of this transform. */
+  bool GetInverse(Self* inverse) const;
+
+  /** Return an inverse of this transform. */
+  virtual InverseTransformBasePointer GetInverseTransform() const;
+
 protected:
   CenteredEuler3DTransform();
   CenteredEuler3DTransform(unsigned int SpaceDimension,
@@ -105,7 +116,7 @@ protected:
 
   /**
    * Print contents of an CenteredEuler3DTransform
-   **/
+   */
   void PrintSelf(std::ostream &os, Indent indent) const;
 
 private:
@@ -117,7 +128,7 @@ private:
 
 }  // namespace itk
 
-// Define instantiation macro for this template.
+/** Define instantiation macro for this template. */
 #define ITK_TEMPLATE_CenteredEuler3DTransform(_, EXPORT, x, y) namespace itk { \
   _(1(class EXPORT CenteredEuler3DTransform< ITK_TEMPLATE_1 x >)) \
   namespace Templates { typedef CenteredEuler3DTransform< ITK_TEMPLATE_1 x > \
