@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNeighborhoodAccessorFunctor.h,v $
   Language:  C++
-  Date:      $Date: 2005-09-07 14:46:28 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-04-21 15:46:16 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -82,9 +82,15 @@ public:
     return boundaryCondition->operator()(point_index, boundary_offset, data);
     }
   
-  void SetVectorLength( VectorLengthType length ) {};
-  VectorLengthType SetVectorLength() { return 0; };
+  void SetVectorLength( VectorLengthType length ) {}
+  VectorLengthType SetVectorLength() { return 0; }
+
+  /** Constructor */
+  NeighborhoodAccessorFunctor() {}
   
+  /** Destructor */
+  virtual ~NeighborhoodAccessorFunctor() {}
+
 };
 
 } // end namespace itk
