@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNumericTraitsRGBPixel.h,v $
   Language:  C++
-  Date:      $Date: 2009-02-06 20:53:13 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-07-30 20:51:30 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,15 +52,15 @@ public: \
  \
   typedef ElementRealType ScalarRealType; \
  \
-  static const RealType max( const Self & a ) \
+  static const Self max( const Self & a ) \
     {  \
-      RealType b;  \
+      Self b;  \
       b.Fill( NumericTraits< T >::max() ); \
       return b; \
     } \
-  static const RealType min( const Self & a ) \
+  static const Self min( const Self & a ) \
     {  \
-      RealType b;  \
+      Self b;  \
       b.Fill( NumericTraits< T >::min() ); \
       return b; \
     } \
