@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPreOrderTreeIterator.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:09 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-03-03 15:08:00 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -19,7 +19,7 @@
 
 #include <itkTreeIteratorBase.h>
 
-namespace itk{
+namespace itk {
 
 template <class TTreeType>
 class PreOrderTreeIterator : public TreeIteratorBase<TTreeType> 
@@ -27,8 +27,8 @@ class PreOrderTreeIterator : public TreeIteratorBase<TTreeType>
 public:
 
   /** Typedefs */
-  typedef typename TTreeType::ValueType  ValueType;
-  typedef TreeIteratorBase<TTreeType> Superclass;
+  typedef typename TTreeType::ValueType     ValueType;
+  typedef TreeIteratorBase<TTreeType>       Superclass;
   typedef typename Superclass::TreeNodeType TreeNodeType;
  
   /** Constructor */
@@ -55,7 +55,7 @@ private:
 
 /** Constructor */
 template <class TTreeType>
-PreOrderTreeIterator<TTreeType>::PreOrderTreeIterator( const TTreeType* tree,const TreeNodeType* start )
+PreOrderTreeIterator<TTreeType>::PreOrderTreeIterator( const TTreeType* tree, const TreeNodeType* start )
   :TreeIteratorBase<TTreeType>(tree,start) 
 {
 
@@ -112,6 +112,12 @@ PreOrderTreeIterator<TTreeType>::FindNextNode() const
   TreeNodeType* child = this->m_Position;
   TreeNodeType* parent = dynamic_cast<TreeNodeType*>(this->m_Position->GetParent());
 
+  // Are we a subtree? Then we are done.
+  if( parent && parent->ChildPosition( this->m_Root ) >= 0 )
+    {
+    return NULL;
+    }
+
   int childPosition = parent->ChildPosition( child ); 
   int lastChildPosition = parent->CountChildren() - 1;
 
@@ -157,7 +163,7 @@ PreOrderTreeIterator<TTreeType>::FindNextNode() const
 template <class TTreeType>
 TreeIteratorBase<TTreeType>* PreOrderTreeIterator<TTreeType>::Clone() 
 {
-  PreOrderTreeIterator<TTreeType>* clone = new PreOrderTreeIterator<TTreeType>(this-> m_Tree, this->m_Position );
+  PreOrderTreeIterator<TTreeType>* clone = new PreOrderTreeIterator<TTreeType>( this->m_Tree, this->m_Position );
   *clone = *this;
   return clone;
 }
