@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransform.h,v $
   Language:  C++
-  Date:      $Date: 2008-01-23 22:44:36 $
-  Version:   $Revision: 1.57 $
+  Date:      $Date: 2009-09-08 01:00:58 $
+  Version:   $Revision: 1.72 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -67,9 +67,9 @@ class ITK_EXPORT  Transform  : public TransformBase
 {
 public:
   /** Standard class typedefs. */
-  typedef Transform  Self;
-  typedef TransformBase Superclass;
-  typedef SmartPointer< Self >   Pointer;
+  typedef Transform                   Self;
+  typedef TransformBase               Superclass;
+  typedef SmartPointer< Self >        Pointer;
   typedef SmartPointer< const Self >  ConstPointer;
   
   /** New method for creating an object using a factory. */
@@ -110,9 +110,21 @@ public:
   typedef vnl_vector_fixed<TScalarType, NOutputDimensions> OutputVnlVectorType;
   
   /** Standard coordinate point type for this class */
-  typedef Point<TScalarType, NInputDimensions> InputPointType;
+  typedef Point<TScalarType, NInputDimensions>  InputPointType;
   typedef Point<TScalarType, NOutputDimensions> OutputPointType;
   
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost. */
+#if _MSC_VER <= 1300
+  // Work-around for a visual c++ 6.0 and 7.0 bug. For details, see
+  // http://www.itk.org/mailman/private/insight-developers/2009-April/012191.html
+  typedef TransformBase                                InverseTransformBaseType;
+#else
+  typedef Transform< 
+    TScalarType, NOutputDimensions, NInputDimensions > InverseTransformBaseType;
+#endif
+  typedef typename InverseTransformBaseType::Pointer   InverseTransformBasePointer;
+  
   /**  Method to transform a point. */
   virtual OutputPointType TransformPoint(const InputPointType  & ) const
     { return OutputPointType(); } 
@@ -138,7 +150,7 @@ public:
    * \sa SetParametersByValue
    */
   virtual void SetParameters( const ParametersType & ) 
-    { itkExceptionMacro( << "Subclasses should override this method" ) };
+    { itkExceptionMacro( << "Subclasses should override this method" ) }
 
   /** Set the transformation parameters and update internal transformation. 
    * This method forces the transform to copy the parameters.  The
@@ -148,21 +160,29 @@ public:
    * \sa SetParameters
    */
   virtual void SetParametersByValue ( const ParametersType & p ) 
-    { this->SetParameters ( p ); };
+    { this->SetParameters ( p ); }
 
   /** Get the Transformation Parameters. */
   virtual const ParametersType& GetParameters(void) const
-    { itkExceptionMacro( << "Subclasses should override this method" );
-      return m_Parameters; };
+    { 
+    itkExceptionMacro( << "Subclasses should override this method" );
+    // Next line is needed to avoid errors due to: 
+    // "function must return a value".
+    return this->m_Parameters; 
+    }
 
   /** Set the fixed parameters and update internal transformation. */
   virtual void SetFixedParameters( const ParametersType & ) 
-    { itkExceptionMacro( << "Subclasses should override this method" ) };
+    { itkExceptionMacro( << "Subclasses should override this method" ) }
 
   /** Get the Fixed Parameters. */
   virtual const ParametersType& GetFixedParameters(void) const
-    { itkExceptionMacro( << "Subclasses should override this method" );
-      return m_Parameters; };
+    {
+    itkExceptionMacro( << "Subclasses should override this method" );
+    // Next line is needed to avoid errors due to: 
+    // "function must return a value".
+    return this->m_FixedParameters;
+    }
 
   /** Compute the Jacobian of the transformation
    *
@@ -176,37 +196,50 @@ public:
    *
    * \f[
    *
-      J=\left[ \begin{array}{cccc}
-      \frac{\partial x_{1}}{\partial p_{1}} & 
-      \frac{\partial x_{1}}{\partial p_{2}} & 
-      \cdots  & \frac{\partial x_{1}}{\partial p_{m}}\\
-      \frac{\partial x_{2}}{\partial p_{1}} & 
-      \frac{\partial x_{2}}{\partial p_{2}} & 
-      \cdots  & \frac{\partial x_{2}}{\partial p_{m}}\\
-      \vdots  & \vdots  & \ddots  & \vdots \\
-      \frac{\partial x_{n}}{\partial p_{1}} & 
-      \frac{\partial x_{n}}{\partial p_{2}} & 
-      \cdots  & \frac{\partial x_{n}}{\partial p_{m}}
-      \end{array}\right] 
+  J=\left[ \begin{array}{cccc}
+  \frac{\partial x_{1}}{\partial p_{1}} & 
+  \frac{\partial x_{1}}{\partial p_{2}} & 
+  \cdots  & \frac{\partial x_{1}}{\partial p_{m}}\\
+  \frac{\partial x_{2}}{\partial p_{1}} & 
+  \frac{\partial x_{2}}{\partial p_{2}} & 
+  \cdots  & \frac{\partial x_{2}}{\partial p_{m}}\\
+  \vdots  & \vdots  & \ddots  & \vdots \\
+  \frac{\partial x_{n}}{\partial p_{1}} & 
+  \frac{\partial x_{n}}{\partial p_{2}} & 
+  \cdots  & \frac{\partial x_{n}}{\partial p_{m}}
+  \end{array}\right] 
    *
    * \f]
-   * **/
+   * */
   virtual const JacobianType & GetJacobian(const InputPointType  &) const
-    { itkExceptionMacro( << "Subclass should override this method" );
-      return m_Jacobian; }; 
+    {
+    itkExceptionMacro( << "Subclass should override this method" );
+    // Next line is needed to avoid errors due to: 
+    // "function must return a value" .
+    return this->m_Jacobian;
+    } 
 
 
   /** Return the number of parameters that completely define the Transfom  */
   virtual unsigned int GetNumberOfParameters(void) const 
-                      { return m_Parameters.Size(); }
+                      { return this->m_Parameters.Size(); }
 
   /** Returns a boolean indicating whether it is possible or not to compute the
    * inverse of this current Transform. If it is possible, then the inverse of
    * the transform is returned in the inverseTransform variable passed by the
    * user.  The inverse is recomputed if this current transform has been modified.
    * This method is intended to be overriden by derived classes.
-   * */
-  bool GetInverse(Self * inverseTransform) const {return false;}
+   * 
+   */
+  bool GetInverse(Self * itkNotUsed(inverseTransform) ) const {return false;}
+
+  /** Return an inverse of this transform. If the inverse has not been
+   *  implemented, return NULL. The type of the inverse transform
+   *  does not necessarily need to match the type of the forward
+   *  transform. This allows one to return a numeric inverse transform
+   *  instead.
+   */
+  virtual InverseTransformBasePointer GetInverseTransform() const { return NULL; }
 
   /** Generate a platform independant name */
   virtual std::string GetTransformTypeAsString() const;
@@ -223,13 +256,13 @@ public:
    * However, transforms for which this is true will overload and reimplement
    * this method accordingly.
    * 
-   **/
+   */
   virtual bool IsLinear() const { return false; }
 
 protected:
   Transform(); 
   Transform(unsigned int Dimension, unsigned int NumberOfParameters);
-  virtual ~Transform() {};
+  virtual ~Transform() {}
 
 
   mutable ParametersType     m_Parameters;
