@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBMPImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-05-26 23:45:03 $
-  Version:   $Revision: 1.31 $  
+  Date:      $Date: 2009-06-16 07:58:47 $
+  Version:   $Revision: 1.32 $  
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -877,17 +877,10 @@ BMPImageIO
   // The specification calls for a signed integer, but
   // here we force it to be an unsigned integer to avoid
   // dealing with directions in a subterraneous way.
-#ifdef ITK_USE_PORTABLE_ROUND
   const unsigned int horizontalResolution = 
     static_cast<unsigned int>( Math::Round( 1000.0 / m_Spacing[0] ) );
   const unsigned int verticalResolution =
     static_cast<unsigned int>( Math::Round( 1000.0 / m_Spacing[1] ) );
-#else
-  const unsigned int horizontalResolution = 
-    static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[0] ) );
-  const unsigned int verticalResolution =
-    static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[1] ) );
-#endif
 
   this->Write32BitsInteger( horizontalResolution );
   this->Write32BitsInteger( verticalResolution );
