@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageSeriesReader.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-24 13:35:59 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-07-30 20:00:00 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,6 +25,7 @@
 #include <vector>
 #include <string>
 #include "itkMetaDataDictionary.h"
+#include "itkImageFileReader.h"
 
 namespace itk
 {
@@ -61,6 +62,9 @@ public:
   /** The size of the output image. */
   typedef typename TOutputImage::SizeType  SizeType;
 
+  /** The index of the output image. */
+  typedef typename TOutputImage::IndexType  IndexType;
+
   /** The region of the output image. */
   typedef typename TOutputImage::RegionType  ImageRegionType;
 
@@ -110,7 +114,7 @@ public:
   /** ReverseOrderOn changes the order of travesal of the file names
    * from last to first */
   itkSetMacro(ReverseOrder,bool);
-  itkGetMacro(ReverseOrder,bool);
+  itkGetConstMacro(ReverseOrder,bool);
   itkBooleanMacro(ReverseOrder);
 
   /** Set/Get the ImageIO helper class. By default, the
@@ -133,9 +137,14 @@ public:
   
   /** Get access to the Array of MetaDataDictionaries */
   DictionaryArrayRawPointer GetMetaDataDictionaryArray() const;
+
+  /** Set the stream On or Off */
+  itkSetMacro(UseStreaming,bool);
+  itkGetConstReferenceMacro(UseStreaming,bool);
+  itkBooleanMacro(UseStreaming);
   
 protected:
-  ImageSeriesReader() : m_ImageIO(0), m_ReverseOrder(false) {};
+  ImageSeriesReader() : m_ImageIO(0), m_ReverseOrder(false), m_UseStreaming(true) {};
   ~ImageSeriesReader();
   void PrintSelf(std::ostream& os, Indent indent) const;
   
@@ -152,16 +161,25 @@ protected:
   FileNamesContainer m_FileNames;
 
   /** The number of independent variables in the images that comprise
-   *  the series. */
+   *  the series. This is also used as the slice moving dimension
+   *  index for the output image. That is for reading a series of 2D
+   *  images into  a 3D image, the moving dimension index is 2.
+   */
   int m_NumberOfDimensionsInImage;
 
   /** Array of MetaDataDictionaries. This allows to hold information from the
    * ImageIO objects after reading every sub image in the series */
   DictionaryArrayType m_MetaDataDictionaryArray;
 
+  bool m_UseStreaming;
+
 private:
   ImageSeriesReader(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
+
+  typedef ImageFileReader<TOutputImage> ReaderType;
+
+  int ComputeMovingDimensionIndex( ReaderType * reader );
 };
 
 } //namespace ITK
