@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSiemensVisionImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-23 15:30:00 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-04-05 23:09:19 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -181,12 +181,12 @@ GEImageHeader *SiemensVisionImageIO::ReadHeader(const char *FileNameToRead)
 
   this->GetStringAt(f, TEXT_FOVH,tmpStr, TEXT_FOVH_LEN);
   tmpStr[TEXT_FOVH_LEN] = '\0';
-  hdr->xFOV = atof(tmpStr);
+  hdr->xFOV = static_cast<float>(atof(tmpStr));
   DB(hdr->xFOV );
   
   this->GetStringAt(f, TEXT_FOVV,tmpStr, TEXT_FOVV_LEN);
   tmpStr[TEXT_FOVV_LEN] = '\0';
-  hdr->yFOV = atof(tmpStr);
+  hdr->yFOV = static_cast<float>(atof(tmpStr));
   DB(hdr->yFOV );
 
   this->GetDoubleAt(f, HDR_PIXELSIZE_ROW,&tmpDble, sizeof (double));
@@ -211,7 +211,7 @@ GEImageHeader *SiemensVisionImageIO::ReadHeader(const char *FileNameToRead)
   
   if (strcmp(tmpStr, "Cor") == 0)
     {
-    if (fabs(atof(tmpStr4))<= 45.0)
+    if (vcl_fabs(atof(tmpStr4))<= 45.0)
       {
       //hdr->imagePlane = itk::IOCommon::ITK_ANALYZE_ORIENTATION_IRP_CORONAL;
       hdr->coordinateOrientation = itk::SpatialOrientation::ITK_COORDINATE_ORIENTATION_RSP;
@@ -232,7 +232,7 @@ GEImageHeader *SiemensVisionImageIO::ReadHeader(const char *FileNameToRead)
     }
   else if (strcmp(tmpStr, "Sag") == 0)
     {
-    if (fabs(atof(tmpStr4))<= 45.0)
+    if (vcl_fabs(atof(tmpStr4))<= 45.0)
       {
       //hdr->imagePlane = itk::SpatialOrientation::ITK_ANALYZE_ORIENTATION_IRP_SAGITTAL;
       hdr->coordinateOrientation = itk::SpatialOrientation::ITK_COORDINATE_ORIENTATION_AIR;
@@ -253,7 +253,7 @@ GEImageHeader *SiemensVisionImageIO::ReadHeader(const char *FileNameToRead)
     }
   else
     {
-    if (fabs(atof(tmpStr4))<= 45.0)
+    if (vcl_fabs(atof(tmpStr4))<= 45.0)
       {
       //hdr->imagePlane = itk::SpatialOrientation::ITK_ANALYZE_ORIENTATION_IRP_TRANSVERSE;
       hdr->coordinateOrientation = itk::SpatialOrientation::ITK_COORDINATE_ORIENTATION_RAI;
@@ -277,7 +277,7 @@ GEImageHeader *SiemensVisionImageIO::ReadHeader(const char *FileNameToRead)
   /* fprintf(stderr, "Plane %d\n", hdr->imagePlane); */
   this->GetStringAt(f, TEXT_SLICE_POS,tmpStr, TEXT_SLICE_POS_LEN);
   tmpStr[TEXT_SLICE_POS_LEN] = '\0';
-  hdr->sliceLocation = atof(tmpStr);
+  hdr->sliceLocation = static_cast<float>(atof(tmpStr));
   DB(hdr->sliceLocation );
 
   /* fprintf(stderr, "Slice Location %f\n", hdr->sliceLocation); */
