@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVTKImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-15 14:03:11 $
-  Version:   $Revision: 1.44 $
+  Date:      $Date: 2009-04-05 10:56:48 $
+  Version:   $Revision: 1.48 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,6 +23,7 @@
 #include <itksys/ios/sstream>
 
 #include <stdio.h>
+#include <string.h>
 
 namespace itk
 {
@@ -64,7 +65,7 @@ bool VTKImageIO::OpenVTKFileForReading(std::ifstream& os,
 #if defined(_WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
   const int openMode = std::ios::in|std::ios::binary;
 #elif ( defined(__GNUC__) && __GNUC__ >= 3 ) || defined (__MWERKS__) || defined (__INTEL_COMPILER) || defined (__MINGW32__) || defined(__CYGWIN__)
-  const std::ios_base::openmode openMode = std::ios::in;
+  const std::ios_base::openmode openMode = std::ios::in|std::ios::binary;
 #else
   const int openMode = std::ios::in;
 #endif
@@ -106,7 +107,7 @@ bool VTKImageIO::OpenVTKFileForWriting(std::ofstream& os,
 #if defined(_WIN32) && !defined(__MINGW32__) && !defined(__CYGWIN__)
   const int openMode = std::ios::out|std::ios::binary;
 #elif (defined(__GNUC__) && __GNUC__ >= 3) || defined (__MWERKS__) || defined (__INTEL_COMPILER) || defined (__MINGW32__) || defined(__CYGWIN__)
-  const std::ios_base::openmode openMode =std::ios::out;
+  const std::ios_base::openmode openMode =std::ios::out|std::ios::binary;
 #else
   const int openMode = std::ios::out;
 #endif
@@ -366,6 +367,8 @@ void VTKImageIO::Read(void* buffer)
 {
   std::ifstream file;
 
+  typedef ::size_t   BufferSizeType;
+
   this->InternalReadImageInformation(file);
   
   //We are positioned at the data. The data is read depending on whether 
@@ -377,18 +380,18 @@ void VTKImageIO::Read(void* buffer)
     }
   else
     {
-    file.read(static_cast<char*>(buffer), this->GetImageSizeInBytes());
+    file.read(static_cast<char*>(buffer), static_cast<std::streamsize>(this->GetImageSizeInBytes()));
     int size = this->GetComponentSize();
     switch( size )
       {
       case 2:
-        ByteSwapper<short>::SwapRangeFromSystemToBigEndian((short *)buffer, this->GetImageSizeInComponents() );
+        ByteSwapper<short>::SwapRangeFromSystemToBigEndian((short *)buffer, static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         break;
       case 4:
-        ByteSwapper<float>::SwapRangeFromSystemToBigEndian((float *)buffer, this->GetImageSizeInComponents() );
+        ByteSwapper<float>::SwapRangeFromSystemToBigEndian((float *)buffer, static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         break;
       case 8:
-        ByteSwapper<double>::SwapRangeFromSystemToBigEndian((double *)buffer, this->GetImageSizeInComponents() );
+        ByteSwapper<double>::SwapRangeFromSystemToBigEndian((double *)buffer, static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         break;
       }
     }
@@ -503,28 +506,29 @@ void VTKImageIO::Write(const void* buffer)
   else //binary
     {
     int size = this->GetComponentSize();
-    const unsigned long int numbytes=this->GetImageSizeInBytes();
+    typedef ::size_t   BufferSizeType;
+    const BufferSizeType numbytes = static_cast<BufferSizeType>( this->GetImageSizeInBytes() );
     char * tempmemory=new char[numbytes];
     memcpy(tempmemory,buffer,numbytes);
     switch( size )
       {
       case 2:
         {
-        ByteSwapper<short>::SwapRangeFromSystemToBigEndian(reinterpret_cast<short *>(tempmemory), this->GetImageSizeInComponents() );
+        ByteSwapper<short>::SwapRangeFromSystemToBigEndian(reinterpret_cast<short *>(tempmemory), static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         }
         break;
       case 4:
         {
-        ByteSwapper<float>::SwapRangeFromSystemToBigEndian(reinterpret_cast<float *>(tempmemory), this->GetImageSizeInComponents() );
+        ByteSwapper<float>::SwapRangeFromSystemToBigEndian(reinterpret_cast<float *>(tempmemory), static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         }
         break;
       case 8:
         {
-        ByteSwapper<double>::SwapRangeFromSystemToBigEndian(reinterpret_cast<double *>(tempmemory), this->GetImageSizeInComponents() );
+        ByteSwapper<double>::SwapRangeFromSystemToBigEndian(reinterpret_cast<double *>(tempmemory), static_cast<BufferSizeType>(this->GetImageSizeInComponents()) );
         }
         break;
       }
-    file.write(static_cast<const char*>(tempmemory), this->GetImageSizeInBytes());
+            file.write(static_cast<const char*>(tempmemory), static_cast<std::streamsize>(this->GetImageSizeInBytes()));
     delete [] tempmemory;
     }
 }
