@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMMaterials.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:43 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-01-30 21:10:19 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,6 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
+#ifndef __itkFEMMaterials_h
+#define __itkFEMMaterials_h
 
 /**
  * \file itkFEMMaterials.h
@@ -24,3 +26,4 @@
  */
 #include "itkFEMMaterialBase.h"
 #include "itkFEMMaterialLinearElasticity.h"
+#endif
