@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTrainingFunctionBase.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-17 13:10:57 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-01-28 21:04:59 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -32,9 +32,9 @@ template<class TSample, class TTargetVector, class ScalarType>
 class TrainingFunctionBase : public LightProcessObject
 {
 public:
-  typedef TrainingFunctionBase Self;
-  typedef LightProcessObject Superclass;
-  typedef SmartPointer<Self> Pointer;
+  typedef TrainingFunctionBase     Self;
+  typedef LightProcessObject       Superclass;
+  typedef SmartPointer<Self>       Pointer;
   typedef SmartPointer<const Self> ConstPointer;
 
   /** Method for creation through the object factory. */
@@ -43,17 +43,17 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  typedef ScalarType ValueType;
-  typedef typename TSample::MeasurementVectorType VectorType;
+  typedef ScalarType                                    ValueType;
+  typedef typename TSample::MeasurementVectorType       VectorType;
   typedef typename TTargetVector::MeasurementVectorType OutputVectorType;
-  typedef Array<ValueType> InternalVectorType;
+  typedef Array<ValueType>                              InternalVectorType;
 
-  typedef std::vector<VectorType> InputSampleVectorType;
-  typedef std::vector<OutputVectorType> OutputSampleVectorType;
+  typedef std::vector<VectorType>                           InputSampleVectorType;
+  typedef std::vector<OutputVectorType>                     OutputSampleVectorType;
   typedef NeuralNetworkObject<VectorType, OutputVectorType> NetworkType;
   typedef ErrorFunctionBase<InternalVectorType, ScalarType> PerformanceFunctionType;
-  typedef SquaredDifferenceErrorFunction<InternalVectorType, ScalarType> DefaultPerformanceType;
-  //typedef MeanSquaredErrorFunction<InternalVectorType, ScalarType> DefaultPerformanceType;
+  typedef SquaredDifferenceErrorFunction<InternalVectorType, ScalarType>
+                                                            DefaultPerformanceType;
 
   void SetTrainingSamples(TSample* samples);
   void SetTargetValues(TTargetVector* targets);
@@ -77,7 +77,7 @@ public:
     VectorType temp;
     for (unsigned int i = 0; i < v.Size(); i++)
       {
-      temp[i] = static_cast<ScalarType>(v[i]) ;
+      temp[i] = static_cast<ScalarType>(v[i]);
       }
     return temp;
     }
@@ -89,7 +89,7 @@ public:
     
     for (unsigned int i = 0; i < v.Size(); i++)
       {
-      temp[i] = static_cast<ScalarType>(v[i]) ;
+      temp[i] = static_cast<ScalarType>(v[i]);
       }
     return temp;
     }
@@ -103,11 +103,12 @@ protected:
   virtual void PrintSelf( std::ostream& os, Indent indent ) const;
 
   TSample*                m_TrainingSamples;// original samples
-  TTargetVector*                m_SampleTargets;  // original samples
+  TTargetVector*          m_SampleTargets;  // original samples
   InputSampleVectorType   m_InputSamples;   // itk::vectors
   OutputSampleVectorType  m_Targets;        // itk::vectors
-  long                    m_Iterations;    
+  long                    m_Iterations;
   ValueType               m_LearningRate;
+
   typename PerformanceFunctionType::Pointer m_PerformanceFunction;
 };
 
