@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLBFGSBOptimizer.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-08 18:01:03 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-06-24 12:02:51 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,9 @@
 #include "vnl/algo/vnl_lbfgsb.h"
 #include <vnl/vnl_math.h>
 
+extern "C" {
+  extern double v3p_netlib_dpmeps_();
+}
 
 namespace itk
 {
@@ -47,7 +50,7 @@ public:
   virtual bool report_iter();
 
 private:
-  LBFGSBOptimizer* m_itkObj;
+  LBFGSBOptimizer*     m_ItkObj;
 };
 
   
@@ -74,6 +77,7 @@ LBFGSBOptimizer
   m_CurrentIteration                = 0;
   m_Value                           = 0.0;
   m_InfinityNormOfProjectedGradient = 0.0;
+  m_StopConditionDescription.str("");
  
 }
 
@@ -386,6 +390,9 @@ LBFGSBOptimizer
 
   ParametersType parameters( this->GetInitialPosition() );
 
+  // Clear the description
+  m_StopConditionDescription.str("");
+
   // vnl optimizers return the solution by reference 
   // in the variable provided as initial position
   m_VnlOptimizer->minimize( parameters );
@@ -409,15 +416,12 @@ LBFGSBOptimizer
  *-------------------------------------------------------------------------
  */
 
-
-
-
 /** Create with a reference to the ITK object */
 LBFGSBOptimizerHelper
 ::LBFGSBOptimizerHelper( vnl_cost_function& f,
                          LBFGSBOptimizer* itkObj )
   : vnl_lbfgsb( f ),
-    m_itkObj( itkObj )
+    m_ItkObj( itkObj )
 {
 }
 
@@ -429,16 +433,19 @@ LBFGSBOptimizerHelper
 {
   Superclass::report_iter();
 
-  m_itkObj->m_InfinityNormOfProjectedGradient =
+  m_ItkObj->m_InfinityNormOfProjectedGradient =
     this->get_inf_norm_projected_gradient();
 
-  m_itkObj->InvokeEvent( IterationEvent() );
+  m_ItkObj->InvokeEvent( IterationEvent() );
 
-  m_itkObj->m_CurrentIteration = this->num_iterations_;
+  m_ItkObj->m_CurrentIteration = this->num_iterations_;
 
   // Return true to terminate the optimization loop.
-  if( this->num_iterations_ > m_itkObj->m_MaximumNumberOfIterations )
+  if( this->num_iterations_ > m_ItkObj->m_MaximumNumberOfIterations )
     {
+    m_ItkObj->m_StopConditionDescription <<
+      "Too many iterations. Iterations = " <<
+      m_ItkObj->m_MaximumNumberOfIterations;
     return true;
     }
   else
@@ -447,6 +454,68 @@ LBFGSBOptimizerHelper
     }
 }
 
+const std::string
+LBFGSBOptimizer::
+GetStopConditionDescription() const
+{
+  if (m_VnlOptimizer)
+    {
+    m_StopConditionDescription.str("");
+    m_StopConditionDescription << this->GetNameOfClass() << ": ";
+    switch (m_VnlOptimizer->get_failure_code())
+      {
+      case vnl_nonlinear_minimizer::ERROR_FAILURE:
+        m_StopConditionDescription << "Failure";
+        break;
+      case vnl_nonlinear_minimizer::ERROR_DODGY_INPUT:
+        m_StopConditionDescription << "Dodgy input";
+        break;
+      case vnl_nonlinear_minimizer::CONVERGED_FTOL:
+        m_StopConditionDescription << "Function tolerance reached after "
+                                   << m_CurrentIteration
+                                   << " iterations. "
+                                   << "The relative reduction of the cost function <= "
+                                   << m_CostFunctionConvergenceFactor * v3p_netlib_dpmeps_()
+                                   << " = CostFunctionConvergenceFactor ("
+                                   << m_CostFunctionConvergenceFactor
+                                   << ") * machine precision ("
+                                   << v3p_netlib_dpmeps_()
+                                   << ").";
+        break;
+      case vnl_nonlinear_minimizer::CONVERGED_XTOL:
+        m_StopConditionDescription << "Solution tolerance reached";
+        break;
+      case vnl_nonlinear_minimizer::CONVERGED_XFTOL:
+        m_StopConditionDescription << "Solution and Function tolerance both reached";
+        break;
+      case vnl_nonlinear_minimizer::CONVERGED_GTOL:
+        m_StopConditionDescription << "Gradient tolerance reached. "
+                                   << "Projected gradient tolerance is "
+                                   << m_ProjectedGradientTolerance;
+        break;
+      case vnl_nonlinear_minimizer::FAILED_TOO_MANY_ITERATIONS:
+        m_StopConditionDescription << "Too many iterations. Iterations = "
+                                   << m_MaximumNumberOfEvaluations;
+        break;
+      case vnl_nonlinear_minimizer::FAILED_FTOL_TOO_SMALL:
+        m_StopConditionDescription << "Function tolerance too small";
+        break;
+      case vnl_nonlinear_minimizer::FAILED_XTOL_TOO_SMALL:
+        m_StopConditionDescription << "Solution tolerance too small";
+        break;
+      case vnl_nonlinear_minimizer::FAILED_GTOL_TOO_SMALL:
+        m_StopConditionDescription << "Gradient tolerance too small";
+        break;
+      case vnl_nonlinear_minimizer::FAILED_USER_REQUEST:
+        break;
+      }
+    return m_StopConditionDescription.str();
+    }
+  else
+    {
+    return std::string("");
+    }
+}
 
 } // end namespace itk
 
