@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPowellOptimizer.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-24 15:43:58 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-06-24 12:02:54 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -127,6 +127,14 @@ public:
   void StopOptimization() 
     { m_Stop = true; }
 
+  itkGetMacro(CatchGetValueException, bool);
+  itkSetMacro(CatchGetValueException, bool);
+
+  itkGetMacro(MetricWorstPossibleValue, double);
+  itkSetMacro(MetricWorstPossibleValue, double);
+
+  const std::string GetStopConditionDescription() const;
+
 protected:
   PowellOptimizer();
   PowellOptimizer(const PowellOptimizer&);
@@ -145,6 +153,8 @@ protected:
    * Line origin and distances are set via SetLine */
   double GetLineValue(double x) const;
 
+  double GetLineValue(double x, ParametersType & tempCoord) const;
+
   /** Set the given scalar step distance (x) and function value (fx) as the
    * "best-so-far" optimizer values. */
   void   SetCurrentLinePoint(double x, double fx);
@@ -169,6 +179,10 @@ protected:
   virtual void   LineBracket(double *ax, double *bx, double *cx,
                              double *fa, double *fb, double *fc);
 
+  virtual void   LineBracket(double *ax, double *bx, double *cx,
+                             double *fa, double *fb, double *fc,
+                             ParametersType & tempCoord);
+
   /** Given a bracketing triple of points and their function values, returns
    * a bounded extreme.  These values are in parameter space, along the 
    * current line and wrt the current origin set via SetLine.   Optimization
@@ -178,8 +192,20 @@ protected:
                                        double fa, double fb, double fc,
                                        double * extX, double * extVal);
 
+  virtual void   BracketedLineOptimize(double ax, double bx, double cx,
+                                       double fa, double fb, double fc,
+                                       double * extX, double * extVal,
+                                       ParametersType & tempCoord);
+
   itkGetMacro(SpaceDimension, unsigned int);
-  itkSetMacro(SpaceDimension, unsigned int);
+  void SetSpaceDimension( unsigned int dim )
+    {
+    this->m_SpaceDimension = dim;
+    this->m_LineDirection.set_size( dim );
+    this->m_LineOrigin.set_size( dim );
+    this->m_CurrentPosition.set_size( dim );
+    this->Modified();
+    }
 
   itkSetMacro(CurrentIteration, unsigned int);
 
@@ -197,6 +223,9 @@ private:
   unsigned int       m_MaximumIteration;
   unsigned int       m_MaximumLineIteration;
 
+  bool               m_CatchGetValueException;
+  double             m_MetricWorstPossibleValue;
+
   /** Set if the Metric should be maximized: Default = False */
   bool               m_Maximize;
 
@@ -218,6 +247,7 @@ private:
    * optimization will stop at the next iteration. */
   bool               m_Stop;
 
+  OStringStream      m_StopConditionDescription;
 }; // end of class
 
 } // end of namespace itk
