@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCylinderSpatialObject.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-04-06 12:50:58 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-05 10:56:52 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -15,6 +15,7 @@
 
 =========================================================================*/
 #include "itkCylinderSpatialObject.h"
+#include <string.h>
 
 namespace itk
 {
@@ -40,12 +41,13 @@ CylinderSpatialObject ::~CylinderSpatialObject()
 bool CylinderSpatialObject
 ::IsInside( const PointType & point) const
 {
-  if(!this->GetIndexToWorldTransform()->GetInverse(const_cast<TransformType *>(this->GetInternalInverseTransform())))
+  if( !this->SetInternalInverseTransformToWorldToIndexTransform() )
     {
     return false;
     }
 
-  PointType transformedPoint = this->GetInternalInverseTransform()->TransformPoint(point);
+  PointType transformedPoint = 
+    this->GetInternalInverseTransform()->TransformPoint(point);
 
   this->ComputeLocalBoundingBox();
 
