@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDTITubeSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:21 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-07 14:33:56 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,19 +26,19 @@ namespace itk
 {
 
 /** 
-* \class DTITubeSpatialObject
-* \brief Representation of a tube based on the spatial object classes.
-*
-* The tube is basically defined by a set of points. Each tube can
-* be connected to a tube network, by using the AddSpatialObject() methods
-* of a DTITubeSpatialObject Object. 
-* A tube is also identified by an id number when connected to a network.
-*
-* \sa DTITubeSpatialObjectPoint 
-*/
+ * \class DTITubeSpatialObject
+ * \brief Representation of a tube based on the spatial object classes.
+ *
+ * The tube is basically defined by a set of points. Each tube can
+ * be connected to a tube network, by using the AddSpatialObject() methods
+ * of a DTITubeSpatialObject Object. 
+ * A tube is also identified by an id number when connected to a network.
+ *
+ * \sa DTITubeSpatialObjectPoint 
+ */
 
 template < unsigned int TDimension = 3 >
-class DTITubeSpatialObject : 
+class ITK_EXPORT DTITubeSpatialObject : 
   public TubeSpatialObject< TDimension, 
                             DTITubeSpatialObjectPoint< TDimension >  >
 {
