@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaImageConverter.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-08 18:56:26 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-07 14:34:06 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -29,7 +29,7 @@ namespace itk
 {
 
 template <unsigned int NDimensions = 3, class PixelType = unsigned char>
-class MetaImageConverter
+class ITK_EXPORT MetaImageConverter
 {
 
 public:
@@ -39,9 +39,9 @@ public:
 
   typedef itk::ImageSpatialObject<NDimensions,PixelType >  SpatialObjectType;
   typedef typename SpatialObjectType::TransformType        TransformType;
-  typedef itk::ImageMaskSpatialObject<NDimensions>          MaskSpatialObjectType;
+  typedef itk::ImageMaskSpatialObject<NDimensions>         MaskSpatialObjectType;
 
-  typedef typename SpatialObjectType::Pointer SpatialObjectPointer;
+  typedef typename SpatialObjectType::Pointer     SpatialObjectPointer;
   typedef typename MaskSpatialObjectType::Pointer MaskSpatialObjectPointer;
 
   SpatialObjectPointer ReadMeta(const char* name);
