@@ -1,3 +1,19 @@
+/*=========================================================================
+
+  Program:   Insight Segmentation & Registration Toolkit
+  Module:    $RCSfile: FilteringExamples8.cxx,v $
+  Language:  C++
+  Date:      $Date: 2009-03-16 21:52:49 $
+  Version:   $Revision: 1.5 $
+
+  Copyright (c) Insight Software Consortium. All rights reserved.
+  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
+
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     PURPOSE.  See the above copyright notices for more information.
+
+=========================================================================*/
 // this file defines the FilterExamples for the test driver
 // and all it expects is that you have a function called RegisterTests
 #if defined(_MSC_VER)
@@ -14,18 +30,20 @@
 
 void RegisterTests()
 {
-REGISTER_TEST(GradientAnisotropicDiffusionImageFilterTest);
-REGISTER_TEST(GradientMagnitudeImageFilterTest);
-REGISTER_TEST(GradientMagnitudeRecursiveGaussianImageFilterTest);
-REGISTER_TEST(LaplacianImageFilterTest);
-REGISTER_TEST(MathematicalMorphologyBinaryFiltersTest);
-REGISTER_TEST(MathematicalMorphologyGrayscaleFiltersTest);
-REGISTER_TEST(MeanImageFilterTest);
-REGISTER_TEST(MedianImageFilterTest);
-REGISTER_TEST(MinMaxCurvatureFlowImageFilterTest);
-REGISTER_TEST(RGBCurvatureAnisotropicDiffusionImageFilterTest);
-REGISTER_TEST(RGBGradientAnisotropicDiffusionImageFilterTest);
-REGISTER_TEST(ZeroCrossingBasedEdgeDetectionImageFilterTest);
+  REGISTER_TEST(GradientAnisotropicDiffusionImageFilterTest);
+  REGISTER_TEST(GradientMagnitudeImageFilterTest);
+  REGISTER_TEST(GradientMagnitudeRecursiveGaussianImageFilterTest);
+  REGISTER_TEST(GradientRecursiveGaussianImageFilterTest);
+  REGISTER_TEST(GradientVectorFlowImageFilterTest);
+  REGISTER_TEST(LaplacianImageFilterTest);
+  REGISTER_TEST(MathematicalMorphologyBinaryFiltersTest);
+  REGISTER_TEST(MathematicalMorphologyGrayscaleFiltersTest);
+  REGISTER_TEST(MeanImageFilterTest);
+  REGISTER_TEST(MedianImageFilterTest);
+  REGISTER_TEST(MinMaxCurvatureFlowImageFilterTest);
+  REGISTER_TEST(RGBCurvatureAnisotropicDiffusionImageFilterTest);
+  REGISTER_TEST(RGBGradientAnisotropicDiffusionImageFilterTest);
+  REGISTER_TEST(ZeroCrossingBasedEdgeDetectionImageFilterTest);
 }
 
 #undef main
@@ -40,6 +58,14 @@ REGISTER_TEST(ZeroCrossingBasedEdgeDetectionImageFilterTest);
 #define main GradientMagnitudeRecursiveGaussianImageFilterTest
 #include "GradientMagnitudeRecursiveGaussianImageFilter.cxx"
 
+#undef main
+#define main GradientVectorFlowImageFilterTest
+#include "GradientVectorFlowImageFilter.cxx"
+
+#undef main
+#define main GradientRecursiveGaussianImageFilterTest
+#include "GradientRecursiveGaussianImageFilter.cxx"
+
 #undef main
 #define main LaplacianImageFilterTest
 #include "LaplacianImageFilter.cxx"
@@ -75,6 +101,3 @@ REGISTER_TEST(ZeroCrossingBasedEdgeDetectionImageFilterTest);
 #undef main
 #define main ZeroCrossingBasedEdgeDetectionImageFilterTest
 #include "ZeroCrossingBasedEdgeDetectionImageFilter.cxx"
-
-
-
