@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration15.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-06-24 12:08:59 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,9 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates a realistic pipeline for solving a full deformable registration problem.
@@ -99,34 +96,33 @@ class CommandIterationUpdate : public itk::Command
 public:
   typedef  CommandIterationUpdate   Self;
   typedef  itk::Command             Superclass;
-  typedef itk::SmartPointer<Self>  Pointer;
+  typedef itk::SmartPointer<Self>   Pointer;
   itkNewMacro( Self );
 protected:
   CommandIterationUpdate() {};
 public:
-  typedef itk::RegularStepGradientDescentOptimizer     OptimizerType;
-  typedef   const OptimizerType   *    OptimizerPointer;
+  typedef itk::RegularStepGradientDescentOptimizer  OptimizerType;
+  typedef   const OptimizerType *                   OptimizerPointer;
 
   void Execute(itk::Object *caller, const itk::EventObject & event)
     {
-      Execute( (const itk::Object *)caller, event);
+    Execute( (const itk::Object *)caller, event);
     }
 
   void Execute(const itk::Object * object, const itk::EventObject & event)
     {
-      OptimizerPointer optimizer = 
-        dynamic_cast< OptimizerPointer >( object );
-      if( !(itk::IterationEvent().CheckEvent( &event )) )
-        {
-        return;
-        }
-      std::cout << optimizer->GetCurrentIteration() << "   ";
-      std::cout << optimizer->GetValue() << "   ";
-      std::cout << std::endl;
+    OptimizerPointer optimizer = 
+      dynamic_cast< OptimizerPointer >( object );
+    if( !(itk::IterationEvent().CheckEvent( &event )) )
+      {
+      return;
+      }
+    std::cout << optimizer->GetCurrentIteration() << "   ";
+    std::cout << optimizer->GetValue() << "   ";
+    std::cout << std::endl;
     }
 };
 
-
 int main( int argc, char *argv[] )
 {
   if( argc < 4 )
@@ -197,6 +193,9 @@ int main( int argc, char *argv[] )
   registration->SetOptimizer(     optimizer     );
   registration->SetInterpolator(  interpolator  );
 
+  // Auxiliary identity transform.
+  typedef itk::IdentityTransform<double,SpaceDimension> IdentityTransformType;
+  IdentityTransformType::Pointer identityTransform = IdentityTransformType::New();
 
 
   //
@@ -337,6 +336,9 @@ int main( int argc, char *argv[] )
     itkProbesStart( "Rigid Registration" );
     registration->StartRegistration(); 
     itkProbesStop( "Rigid Registration" );
+    std::cout << "Optimizer stop condition = "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -446,7 +448,7 @@ int main( int argc, char *argv[] )
   SpacingType spacing = fixedImage->GetSpacing();
 
   typedef DeformableTransformType::OriginType OriginType;
-  OriginType origin = fixedImage->GetOrigin();;
+  OriginType origin = fixedImage->GetOrigin();
 
   FixedImageType::SizeType fixedImageSize = fixedRegion.GetSize();
 
@@ -454,13 +456,17 @@ int main( int argc, char *argv[] )
     {
     spacing[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
                   static_cast<double>(gridSizeOnImage[r] - 1);
-    origin[r]  -=  spacing[r]; 
     }
 
+  FixedImageType::DirectionType gridDirection = fixedImage->GetDirection();
+  SpacingType gridOriginOffset = gridDirection * spacing;
+
+  OriginType gridOrigin = origin - gridOriginOffset; 
+
   bsplineTransformCoarse->SetGridSpacing( spacing );
-  bsplineTransformCoarse->SetGridOrigin( origin );
+  bsplineTransformCoarse->SetGridOrigin( gridOrigin );
   bsplineTransformCoarse->SetGridRegion( bsplineRegion );
-  bsplineTransformCoarse->SetGridDirection( fixedImage->GetDirection() );
+  bsplineTransformCoarse->SetGridDirection( gridDirection );
   
   bsplineTransformCoarse->SetBulkTransform( affineTransform );
 
@@ -524,9 +530,6 @@ int main( int argc, char *argv[] )
   // image.
   metric->SetNumberOfSpatialSamples( numberOfBSplineParameters * 100 );
 
-
-
-
   std::cout << std::endl << "Starting Deformable Registration Coarse Grid" << std::endl;
 
   try 
@@ -574,19 +577,24 @@ int main( int argc, char *argv[] )
   bsplineRegion.SetSize( totalGridSize );
 
   SpacingType spacingHigh = fixedImage->GetSpacing();
-  OriginType  originHigh  = fixedImage->GetOrigin();;
+  OriginType  originHigh  = fixedImage->GetOrigin();
 
   for(unsigned int rh=0; rh<ImageDimension; rh++)
     {
     spacingHigh[rh] *= static_cast<double>(fixedImageSize[rh] - 1)  / 
-                       static_cast<double>(gridHighSizeOnImage[rh] - 1);
-    originHigh[rh]  -=  spacingHigh[rh]; 
+      static_cast<double>(gridHighSizeOnImage[rh] - 1);
+    originHigh[rh] -= spacingHigh[rh]; 
     }
 
+  SpacingType gridOriginOffsetHigh = gridDirection * spacingHigh;
+
+  OriginType gridOriginHigh = origin - gridOriginOffsetHigh; 
+
+
   bsplineTransformFine->SetGridSpacing( spacingHigh );
-  bsplineTransformFine->SetGridOrigin( originHigh );
+  bsplineTransformFine->SetGridOrigin( gridOriginHigh );
   bsplineTransformFine->SetGridRegion( bsplineRegion );
-  bsplineTransformFine->SetGridDirection( fixedImage->GetDirection() );
+  bsplineTransformFine->SetGridDirection( gridDirection );
 
   bsplineTransformFine->SetBulkTransform( affineTransform );
 
@@ -616,12 +624,9 @@ int main( int argc, char *argv[] )
     typedef itk::BSplineResampleImageFunction<ParametersImageType,double> FunctionType;
     FunctionType::Pointer function = FunctionType::New();
 
-    typedef itk::IdentityTransform<double,SpaceDimension> IdentityTransformType;
-    IdentityTransformType::Pointer identity = IdentityTransformType::New();
-
     upsampler->SetInput( bsplineTransformCoarse->GetCoefficientImage()[k] );
     upsampler->SetInterpolator( function );
-    upsampler->SetTransform( identity );
+    upsampler->SetTransform( identityTransform );
     upsampler->SetSize( bsplineTransformFine->GetGridRegion().GetSize() );
     upsampler->SetOutputSpacing( bsplineTransformFine->GetGridSpacing() );
     upsampler->SetOutputOrigin( bsplineTransformFine->GetGridOrigin() );
@@ -702,7 +707,7 @@ int main( int argc, char *argv[] )
   // Software Guide : EndCodeSnippet
 
 
-  std::cout << "Deformable Registration Coarse Grid completed" << std::endl;
+  std::cout << "Deformable Registration Fine Grid completed" << std::endl;
   std::cout << std::endl;
 
 
@@ -755,6 +760,7 @@ int main( int argc, char *argv[] )
   caster->SetInput( resample->GetOutput() );
   writer->SetInput( caster->GetOutput()   );
 
+  std::cout << "Writing resampled moving image...";
 
   try
     {
@@ -767,6 +773,7 @@ int main( int argc, char *argv[] )
     return EXIT_FAILURE;
     } 
  
+  std::cout << " Done!" << std::endl;
 
 
   typedef itk::SquaredDifferenceImageFilter< 
@@ -787,6 +794,9 @@ int main( int argc, char *argv[] )
     difference->SetInput1( fixedImageReader->GetOutput() );
     difference->SetInput2( resample->GetOutput() );
     writer2->SetFileName( argv[4] );
+
+    std::cout << "Writing difference image after registration...";
+
     try
       {
       writer2->Update();
@@ -797,6 +807,8 @@ int main( int argc, char *argv[] )
       std::cerr << err << std::endl; 
       return EXIT_FAILURE;
       } 
+
+    std::cout << " Done!" << std::endl;
     }
 
 
@@ -806,7 +818,10 @@ int main( int argc, char *argv[] )
     {
     writer2->SetFileName( argv[5] );
     difference->SetInput1( fixedImageReader->GetOutput() );
-    difference->SetInput2( movingImageReader->GetOutput() );
+    resample->SetTransform( identityTransform );
+
+    std::cout << "Writing difference image before registration...";
+
     try
       {
       writer2->Update();
@@ -817,22 +832,23 @@ int main( int argc, char *argv[] )
       std::cerr << err << std::endl; 
       return EXIT_FAILURE;
       } 
+
+    std::cout << " Done!" << std::endl;
     }
 
-
-
   // Generate the explicit deformation field resulting from 
   // the registration.
   if( argc > 6 )
     {
 
-    typedef itk::Vector< float, ImageDimension >  VectorType;
+    typedef itk::Vector< float, ImageDimension >      VectorType;
     typedef itk::Image< VectorType, ImageDimension >  DeformationFieldType;
 
     DeformationFieldType::Pointer field = DeformationFieldType::New();
     field->SetRegions( fixedRegion );
     field->SetOrigin( fixedImage->GetOrigin() );
     field->SetSpacing( fixedImage->GetSpacing() );
+    field->SetDirection( fixedImage->GetDirection() );
     field->Allocate();
 
     typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
@@ -862,6 +878,9 @@ int main( int argc, char *argv[] )
     fieldWriter->SetInput( field );
 
     fieldWriter->SetFileName( argv[6] );
+
+    std::cout << "Writing deformation field ...";
+
     try
       {
       fieldWriter->Update();
@@ -872,15 +891,19 @@ int main( int argc, char *argv[] )
       std::cerr << excp << std::endl;
       return EXIT_FAILURE;
       }
+
+    std::cout << " Done!" << std::endl;
     }
 
   // Optionally, save the transform parameters in a file
   if( argc > 9 )
     {
+    std::cout << "Writing transform parameter file ...";
     std::ofstream parametersFile;
     parametersFile.open( argv[9] );
     parametersFile << finalParameters << std::endl;
     parametersFile.close();
+    std::cout << " Done!" << std::endl;
     }
 
   return EXIT_SUCCESS;
@@ -890,4 +913,3 @@ int main( int argc, char *argv[] )
 #undef itkProbesStart
 #undef itkProbesStop
 #undef itkProbesReport
-
