@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: HoughTransform2DCirclesImageFilter.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-01 13:09:18 $
-  Version:   $Revision: 1.18 $
+  Date:      $Date: 2009-04-06 00:05:54 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,9 +22,6 @@
 #define ITK_LEAN_AND_MEAN
 #endif
 
-
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates the use of the
@@ -196,7 +193,7 @@ int main( int argc, char *argv[] )
   //  Software Guide : EndLatex 
 
   // Software Guide : BeginCodeSnippet
-  typedef  unsigned char    OutputPixelType;
+  typedef  unsigned char                            OutputPixelType;
   typedef  itk::Image< OutputPixelType, Dimension > OutputImageType;  
 
   OutputImageType::Pointer  localOutputImage = OutputImageType::New();
@@ -240,10 +237,10 @@ int main( int argc, char *argv[] )
       {
       localIndex[0] =
          (long int)((*itCircles)->GetObjectToParentTransform()->GetOffset()[0]
-                                  + (*itCircles)->GetRadius()[0]*cos(angle));
+                                  + (*itCircles)->GetRadius()[0]*vcl_cos(angle));
       localIndex[1] =
          (long int)((*itCircles)->GetObjectToParentTransform()->GetOffset()[1] 
-                                  + (*itCircles)->GetRadius()[0]*sin(angle));
+                                  + (*itCircles)->GetRadius()[0]*vcl_sin(angle));
       OutputImageType::RegionType outputRegion =
                                   localOutputImage->GetLargestPossibleRegion();
 
@@ -282,6 +279,3 @@ int main( int argc, char *argv[] )
 
   return 0;
 }
-
-
-
