@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageEntropy1.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-25 17:13:07 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-07 13:28:38 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -243,7 +243,7 @@ int main( int argc, char * argv [] )
 
     if( probability > 0.99 / Sum )
       {
-      Entropy += - probability * log( probability ) / log( 2.0 );
+      Entropy += - probability * vcl_log( probability ) / vcl_log( 2.0 );
       }
     ++itr;
     }
