@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineDecompositionImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:05 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-07-12 10:52:59 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -46,11 +46,12 @@ int itkBSplineDecompositionImageFilterTest(int, char* [] )
   const unsigned int SplineOrder = 3;
 
   /** Generate a random input image and connect to BSpline decomposition filter */
-  typedef itk::FixedArray<float,ImageDimension> FloatArrayType;
-  typedef itk::FixedArray<unsigned long, ImageDimension> SizeType;
+  typedef ImageType::SpacingType  SpacingType;
+  typedef ImageType::PointType    PointType;
+  typedef ImageType::SizeType     SizeType;
 
-  FloatArrayType spacing;
-  FloatArrayType origin;
+  SpacingType    spacing;
+  PointType      origin;
   SizeType       size;
 
   spacing.Fill( 2.0 );
@@ -60,9 +61,9 @@ int itkBSplineDecompositionImageFilterTest(int, char* [] )
   typedef itk::RandomImageSource<ImageType> SourceType;
   SourceType::Pointer source = SourceType::New();
 
-  source->SetSize( size.GetDataPointer() );
-  source->SetSpacing( spacing.GetDataPointer() );
-  source->SetOrigin( origin.GetDataPointer() );
+  source->SetSize( size );
+  source->SetSpacing( spacing );
+  source->SetOrigin( origin );
 
   source->SetMin( 0.0 );
   source->SetMax( 10.0 );
