@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBinaryMaskToNarrowBandPointSetFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-06 11:27:12 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -102,10 +102,10 @@ int itkBinaryMaskToNarrowBandPointSetFilterTest(int , char *[] )
     {
     narrowBandGenerator->Update();
     } 
-  catch( itk::ExceptionObject & exp )
+  catch( itk::ExceptionObject & excp )
     {
     std::cerr << "Exception thrown during the excecution of the generator " << std::endl;
-    std::cerr << exp << std::endl;
+    std::cerr << excp << std::endl;
     return EXIT_FAILURE;
     }
 
