@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkBloxBoundaryProfileImageToBloxCoreAtomImageFilterTest.cxx,v $
 Language:  C++
-Date:      $Date: 2006-03-06 21:56:45 $
-Version:   $Revision: 1.4 $
+Date:      $Date: 2009-07-12 10:53:00 $
+Version:   $Revision: 1.5 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -49,15 +49,15 @@ int itkBloxBoundaryProfileImageToBloxCoreAtomImageFilterTest(int, char*[])
   const unsigned int dim = 3;
   const unsigned int size = 20;
 
+  // Image typedef
+  typedef itk::Image< unsigned char, dim > ImageType;
+
   //-----------------Create a new input image--------------------
 
   // Image size and spacing parameters
-  unsigned long sourceImageSize[]  = { size,size,size };
-  double sourceImageSpacing[] = { 1.0,1.0,1.0 };
-  double sourceImageOrigin[] = { 0,0,0 };
-
-  // Image typedef
-  typedef itk::Image< unsigned char, dim > ImageType;
+  ImageType::SizeValueType     sourceImageSize[]  = { size,size,size };
+  ImageType::SpacingValueType  sourceImageSpacing[] = { 1.0,1.0,1.0 };
+  ImageType::PointValueType    sourceImageOrigin[] = { 0,0,0 };
 
   // Creates the sourceImage (but doesn't set the size or allocate memory)
   ImageType::Pointer sourceImage = ImageType::New();
