@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFlipImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-04-18 18:16:36 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-06-16 07:58:47 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -114,7 +114,7 @@ int itkFlipImageFilterTest(int, char* [] )
         {
         double temp = - 1 * ( static_cast<double>( inputIndex[j] ) * 
            inputSpacing[j] + inputOrigin[j]);
-        outputIndex[j] = static_cast<IndexValueType>( vnl_math_rnd(( temp - outputOrigin[j] ) / 
+        outputIndex[j] = static_cast<IndexValueType>( itk::Math::Round(( temp - outputOrigin[j] ) / 
            outputSpacing[j] ) );
         }
       else
