@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImportImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-24 15:20:10 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2009-06-01 17:19:32 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -54,7 +54,7 @@ int itkImportImageTest(int, char* [] )
   itk::ShrinkImageFilter<ImportImageFilter::OutputImageType, ShortImage >::Pointer shrink;
   shrink = itk::ShrinkImageFilter<ImportImageFilter::OutputImageType, ShortImage>::New();
   shrink->SetInput( import->GetOutput() );
-  shrink->SetShrinkFactors(2);
+  shrink->SetShrinkFactors(2); //Also tested with factors 3 and 4, with 12x12 image
   try
     {
     shrink->Update();
@@ -100,13 +100,36 @@ int itkImportImageTest(int, char* [] )
   for (; !iterator2.IsAtEnd(); ++iterator2)
     {
     std::cout << "Pixel " << iterator2.GetIndex() << " = " << iterator2.Get() << std::endl;
+#ifdef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
     if ( iterator2.Get() != 
-         static_cast<long>( (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0])
-                          +(region.GetSize()[0]
-                          * shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[1])))
+         itk::Math::RoundHalfIntegerUp(
+            static_cast<float>( (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                                 shrink->GetShrinkFactors()[0]/2) +
+            (region.GetSize()[0] * ((shrink->GetShrinkFactors()[1]/2) +
+                                    (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[1]))))))
       {
+         std::cout << " iterator2.GetIndex() Get() " << iterator2.GetIndex() <<  " " << iterator2.Get()
+                   << " compare value " << itk::Math::RoundHalfIntegerUp(
+            static_cast<float>( (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                                 shrink->GetShrinkFactors()[0]/2) +
+            (region.GetSize()[0] * ((shrink->GetShrinkFactors()[1]/2) +
+                                    (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[1]))))) << "\n";
       passed = false;
       }
+#else 
+    if ( iterator2.Get() != 
+         static_cast<long>( (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] )
+                          +(region.GetSize()[0]
+                            * shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[1])))
+      {
+         std::cout << " iterator2.GetIndex() Get() " << iterator2.GetIndex() <<  " " << iterator2.Get()
+                   << " compare value " << static_cast<long>(
+                      (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] )
+                          + (region.GetSize()[0]
+                             * shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[1])) << "\n"; 
+      passed = false;
+      }
+#endif
     }
 
   if (passed)
