@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRelabelComponentImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:02 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-05-02 05:44:01 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -62,7 +62,13 @@ int itkRelabelComponentImageFilterTest(int argc, char* argv[] )
   typedef itk::LabelStatisticsImageFilter< InternalImageType, LabelImageType> StatisticsFilterType;
 
   typedef itk::NumericTraits<InternalPixelType>::RealType RealType;
+
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef itk::Statistics::Histogram<RealType> HistogramType;
+#else
   typedef itk::Statistics::Histogram<RealType,1> HistogramType;
+#endif
+
   typedef HistogramType::IndexType HIndexType;
   int NumBins = 13;
   RealType LowerBound = 51.0;
