@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkShrinkImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:07 $
-  Version:   $Revision: 1.31 $
+  Date:      $Date: 2009-05-21 19:41:40 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -94,25 +94,73 @@ int itkShrinkImageTest(int, char* [] )
   itk::ImageRegionIterator<ShortImage>
     iterator2(shrink->GetOutput(), requestedRegion);
 
-  bool passed = true;
-  std::cout << "Output image" << std::endl;
-  std::cout << std::flush;
-  for (; !iterator2.IsAtEnd(); ++iterator2)
+  // If size is not a multiple of the shrink factors, then adjust the
+  // row/col indicies
+  short rowOffset = 0;
+  short colOffset = 0;
+  if (region.GetSize()[1] % shrink->GetShrinkFactors()[1])
     {
-    std::cout << "Pixel " << iterator2.GetIndex() << " = " << iterator2.Get()
-              << std::endl;
-    std::cout << std::flush;
+    rowOffset = static_cast<short>(
+      region.GetSize()[1] / 2.0 -
+      ((region.GetSize()[1] / shrink->GetShrinkFactors()[1]) / 2.0 *
+       shrink->GetShrinkFactors()[1])
+      );
+    }
+  if (region.GetSize()[0] % shrink->GetShrinkFactors()[0])
+    {
+    colOffset = static_cast<short>(
+      region.GetSize()[0] / 2.0 -
+      ((region.GetSize()[0] / shrink->GetShrinkFactors()[0]) / 2.0 *
+       shrink->GetShrinkFactors()[0])
+      );
+    }
 
-    short trueValue = static_cast<short>((shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0])
-              + (region.GetSize()[0]
-                * shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1]));
+  bool passed = true;
+#ifdef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
+ for (; !iterator2.IsAtEnd(); ++iterator2)
+    {
+    short col = itk::Math::RoundHalfIntegerUp(shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                                              (shrink->GetShrinkFactors()[0]-1.0) / 2.0);
+    col += colOffset;
+
+    short row = itk::Math::RoundHalfIntegerUp(shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+                                              (shrink->GetShrinkFactors()[1] - 1.0) / 2.0);
+    row += rowOffset;
+    short trueValue = col + region.GetSize()[0] * row;
 
     if ( iterator2.Get() != trueValue )
       {
       passed = false;
+      std::cout << "Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
       }
     }
 
+#else
+  for (; !iterator2.IsAtEnd(); ++iterator2)
+    {
+    short col = (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                 (shrink->GetShrinkFactors()[0] - 1) / 2);
+    col += colOffset;
+
+    short row = (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+                 (shrink->GetShrinkFactors()[1] - 1) / 2);
+    row += rowOffset;
+    short trueValue = col + region.GetSize()[0] * row;    
+    if ( iterator2.Get() != trueValue )
+      {
+      passed = false;
+      std::cout << "A) Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
+      }
+    }
+#endif
+
+
   // Now test shrinking by 2x2
   std::cout << "Shrink the image by (2,2) instead." << std::endl;
   std::cout << std::flush;
@@ -186,15 +234,40 @@ int itkShrinkImageTest(int, char* [] )
               << std::endl;
     std::cout << std::flush;
 
-    short trueValue = static_cast<short>((shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0])
-              + (region.GetSize()[0]
-                * shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1]));
-
+#ifdef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
+    short trueValue =
+       itk::Math::RoundHalfIntegerUp((shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                                      (shrink->GetShrinkFactors()[0] - 1.0) / 2.0)) +
+       (region.GetSize()[0] * itk::Math::RoundHalfIntegerUp((shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+                                                            (shrink->GetShrinkFactors()[1] - 1.0) / 2.0)));
     if ( iterator2.Get() != trueValue )
       {
+      std::cout << "B) Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
+      passed = false;
+      }    
+    }
+
+#else
+    short trueValue =
+      static_cast<short>(
+        (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+         (shrink->GetShrinkFactors()[0] - 1) / 2)
+        + (region.GetSize()[0]
+           * (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+              (shrink->GetShrinkFactors()[1] - 1) / 2)));
+    if ( iterator2.Get() != trueValue )
+      {
+      std::cout << "B) Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
       passed = false;
       }
     }
+#endif
   
   std::cout << std::endl;
   std::cout << std::flush;
