@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCenteredVersorTransformInitializerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-04-05 10:56:55 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-08-17 23:28:52 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -209,6 +209,29 @@ int itkCenteredVersorTransformInitializerTest(int , char* [] )
       break;
       }
     }
+
+  initializer->ComputeRotationOn();
+  initializer->InitializeTransform();
+
+  TransformType::InputPointType mappedOrigin = transform->TransformPoint( fixedOrigin );
+  TransformType::InputPointType expectedPoint;
+  expectedPoint[0] = 29.0; 
+  expectedPoint[1] = 165.75; 
+  expectedPoint[2] = 13.25;
+
+  for(unsigned int j=0; j < Dimension; j++ )
+    {
+    if( vcl_fabs( expectedPoint[j] - mappedOrigin[j] ) > tolerance )
+      {
+      std::cerr << "Mapped point differs from expected point" << std::endl;
+      std::cerr << "It should be " << expectedPoint << std::endl;
+      std::cerr << "but it is    " << mappedOrigin << std::endl;
+      pass = false;
+      break;
+      }
+    }
+
+
   }
 
 
