@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSymmetricSecondRankTensorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-10 22:48:13 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -239,7 +239,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "EigenAnalysis computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -250,7 +250,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int j=0; j<3; j++)
         {
-        if( fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
+        if( vcl_fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
           {
           std::cerr << "EigenValues computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -292,7 +292,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "EigenAnalysis computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -303,7 +303,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int j=0; j<3; j++)
         {
-        if( fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
+        if( vcl_fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
           {
           std::cerr << "EigenValues computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -346,7 +346,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "Eigenvalue computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -357,7 +357,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
 
       for(unsigned int j=0; j<3; j++)
         {
-        if( fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
+        if( vcl_fabs( expectedValues[j] - eigenValues2[j] ) > tolerance )
           {
           std::cerr << "EigenValues computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -399,7 +399,7 @@ int itkSymmetricSecondRankTensorTest(int, char* [] )
     const double tolerance = 1e-4;
 
     AccumulateValueType computedTrace = tensor3D.GetTrace();
-    if( fabs( computedTrace - expectedTrace ) > tolerance )
+    if( vcl_fabs( computedTrace - expectedTrace ) > tolerance )
       {
       std::cerr << "Error computing the Trace" << std::endl;
       std::cerr << "Expected trace = " << expectedTrace << std::endl;
