@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkNiftiImageIOTest.cxx,v $
 Language:  C++
-Date:      $Date: 2008-09-16 17:29:23 $
-Version:   $Revision: 1.20 $
+Date:      $Date: 2009-05-15 12:14:13 $
+Version:   $Revision: 1.37 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,41 +18,17 @@ PURPOSE.  See the above copyright notices for more information.
 #pragma warning ( disable : 4786 )
 #endif
 
-#include <fstream>
-#include <string.h>
-#include "itkImageFileReader.h"
-#include "itkImage.h"
+#include "itkNiftiImageIOTest.h"
 
-#include <itksys/SystemTools.hxx>
-#include "itkImageRegionIterator.h"
-#include <iostream>
-#include <fstream>
-#include <stdio.h>
 
-#include "itkImageFileWriter.h"
-#include "itkImageIOFactory.h"
-#include "itkNiftiImageIOFactory.h"
-#include "itkNiftiImageIO.h"
-#include "itkMetaDataObject.h"
-#include "itkIOCommon.h"
-#include "itkSpatialOrientationAdapter.h"
-
-#include "itkAffineTransform.h"
-#include "itkVector.h"
-#include <vnl/vnl_math.h>
-
-#include <nifti1_io.h>
-
-static inline int Remove(const char *fname)
+static void RemoveByteSwapTestFiles(void)
 {
-  return itksys::SystemTools::RemoveFile(fname);
+  Remove("NiftiLittleEndian.hdr");
+  Remove("NiftiLittleEndian.img");
+  Remove("NiftiBigEndian.hdr");
+  Remove("NiftiBigEndian.img");
 }
 
-const unsigned char RPI=16;        /*Bit pattern 0 0 0  10000*/
-const unsigned char LEFT=128;      /*Bit pattern 1 0 0  00000*/
-const unsigned char ANTERIOR=64;   /*Bit pattern 0 1 0  00000*/
-const unsigned char SUPERIOR=32;   /*Bit pattern 0 0 1  00000*/
-
 //The WriteTestFiles function writes binary data to disk to ensure that both big and little endian files are available.
 //This allows all the data necessary to create the images to be stored in source files rather than have separate reference images.
 static int WriteTestFiles(void)
@@ -96,19 +72,10 @@ static int WriteTestFiles(void)
   return EXIT_SUCCESS;
 }
 
-static void RemoveByteSwapTestFiles(void)
-{
-  Remove("NiftiLittleEndian.hdr");
-  Remove("NiftiLittleEndian.img");
-  Remove("NiftiBigEndian.hdr");
-  Remove("NiftiBigEndian.img");
-}
-
 static int TestByteSwap(void)
 {
   int rval;
   typedef itk::Image<double, 3> ImageType ;
-  typedef itk::ImageFileReader< ImageType > ImageReaderType ;
   if(WriteTestFiles() == -1)
     {
       return EXIT_FAILURE;
@@ -117,24 +84,19 @@ static int TestByteSwap(void)
   ImageType::Pointer little;
   ImageType::Pointer big;
 
-  itk::ImageFileReader<ImageType>::Pointer imageReader =
-    itk::ImageFileReader<ImageType>::New();
   try
-  {
-    imageReader->SetFileName("NiftiLittleEndian.hdr") ;
-    imageReader->Update() ;
-    little = imageReader->GetOutput() ;
-    imageReader->SetFileName("NiftiBigEndian.hdr") ;
-    imageReader->Update() ;
-    big = imageReader->GetOutput();
+    {
+    little = ReadImage<ImageType>(std::string("NiftiLittleEndian.hdr"), false);
+    const std::string fname("NiftiBigEndian.hdr");
+    big = ReadImage<ImageType>(fname, false);
     std::cout << "Printing Dictionary" << std::endl;
     big->GetMetaDataDictionary().Print(std::cout);
-  }
+    }
   catch (itk::ExceptionObject &e)
     {
-      e.Print(std::cerr) ;
-      RemoveByteSwapTestFiles();
-      return EXIT_FAILURE;
+    e.Print(std::cerr) ;
+    RemoveByteSwapTestFiles();
+    return EXIT_FAILURE;
     }
   rval = 0;
   try
@@ -163,130 +125,6 @@ static int TestByteSwap(void)
   return rval;
 }
 
-template <typename T> int MakeNiftiImage(void)
-{
-  typedef itk::Image<T, 3> ImageType ;
-  typedef itk::ImageFileReader< ImageType > ImageReaderType ;
-  const char *filename = "test.nii";
-  //Allocate Images
-  enum { ImageDimension = ImageType::ImageDimension };
-  typename ImageType::Pointer img;
-  const typename ImageType::SizeType size = {{10,10,10}};
-  const typename ImageType::IndexType index = {{0,0,0}};
-  typename ImageType::RegionType region;
-  region.SetSize( size );
-  region.SetIndex( index );
-
-  img = ImageType::New();
-  img->SetLargestPossibleRegion( region );
-  img->SetBufferedRegion( region );
-  img->SetRequestedRegion( region );
-  img->Allocate();
-
-  { //Fill in entire image
-    itk::ImageRegionIterator<ImageType> ri(img,region);
-    try
-      {
-        while(!ri.IsAtEnd())
-          {
-            ri.Set( RPI );
-            ++ri;
-          }
-      }
-    catch ( itk::ExceptionObject & ex )
-      {
-        std::cerr << "Error filling array" << ex << std::endl;
-        return EXIT_FAILURE;
-      }
-  }
-  { //Fill in left half
-    const typename ImageType::IndexType RPIindex = {{0,0,0}};
-    const typename ImageType::SizeType RPIsize = {{5,10,10}};
-    typename ImageType::RegionType RPIregion;
-    RPIregion.SetSize( RPIsize );
-    RPIregion.SetIndex( RPIindex );
-    itk::ImageRegionIterator<ImageType > RPIiterator(img,RPIregion);
-    while(!RPIiterator.IsAtEnd())
-      {
-        RPIiterator.Set( RPIiterator.Get() + LEFT );
-        ++RPIiterator;
-      }
-  }
-  { //Fill in anterior half
-    const typename ImageType::IndexType RPIindex = {{0,5,0}};
-    const typename ImageType::SizeType RPIsize = {{10,5,10}};
-    typename ImageType::RegionType RPIregion;
-    RPIregion.SetSize( RPIsize );
-    RPIregion.SetIndex( RPIindex );
-    itk::ImageRegionIterator<ImageType > RPIiterator(img,RPIregion);
-    while(!RPIiterator.IsAtEnd())
-      {
-        RPIiterator.Set( RPIiterator.Get() + ANTERIOR );
-        ++RPIiterator;
-      }
-  }
-  { //Fill in superior half
-    const typename ImageType::IndexType RPIindex = {{0,0,5}};
-    const typename ImageType::SizeType RPIsize = {{10,10,5}};
-    typename ImageType::RegionType RPIregion;
-    RPIregion.SetSize( RPIsize );
-    RPIregion.SetIndex( RPIindex );
-    itk::ImageRegionIterator<ImageType > RPIiterator(img,RPIregion);
-    while(!RPIiterator.IsAtEnd())
-      {
-        RPIiterator.Set( RPIiterator.Get() + SUPERIOR );
-        ++RPIiterator;
-      }
-  }
-  typedef itk::ImageFileWriter< ImageType >      ImageWriterType;
-  typename ImageWriterType::Pointer ImageWriterPointer =
-    ImageWriterType::New();
-
-  //Set the output filename
-  ImageWriterPointer->SetFileName(filename);
-
-  //Attach input image to the writer.
-  ImageWriterPointer->SetInput( img );
-  //Determine file type and instantiate appropriate ImageIO class if not
-  //explicitly stated with SetImageIO, then write to disk.
-  try {
-    ImageWriterPointer->Write();
-  }
-  catch ( itk::ExceptionObject & ex )
-    {
-      std::string message;
-      message = "Problem found while writing image ";
-      message += filename;
-      message += "\n";
-      message += ex.GetLocation();
-      message += "\n";
-      message += ex.GetDescription();
-      std::cerr << message << std::endl;
-      Remove(filename);
-      return EXIT_FAILURE;
-    }
-
-  //typedef itk::ImageFileReader< ImageType > ImageReaderType ;
-  typename ImageType::Pointer input;
-  typename itk::ImageFileReader<ImageType>::Pointer imageReader =
-    itk::ImageFileReader<ImageType>::New();
-  try
-    {
-      imageReader->SetFileName(filename) ;
-      imageReader->Update() ;
-      input = imageReader->GetOutput() ;
-    }
-  catch (itk::ExceptionObject &e)
-    {
-      e.Print(std::cerr) ;
-      Remove(filename);
-      return EXIT_FAILURE;
-    }
-  Remove(filename);
-  return EXIT_SUCCESS;
-}
-
-//template int MakeNiftiImage<char>();
 
 int itkNiftiImageIOTest(int ac, char* av[])
 {
@@ -310,16 +148,12 @@ int itkNiftiImageIOTest(int ac, char* av[])
     {
       typedef itk::Image<unsigned char, 3> ImageType ;
       ImageType::Pointer input;
-      itk::ImageFileReader<ImageType>::Pointer imageReader =
-        itk::ImageFileReader<ImageType>::New();
       for(int imagenameindex=1; imagenameindex < ac; imagenameindex++)
         {
           //std::cout << "Attempting to read " << av[imagenameindex] << std::endl;
           try
             {
-              imageReader->SetFileName(av[imagenameindex]) ;
-              imageReader->Update() ;
-              input=imageReader->GetOutput() ;
+            input = ReadImage<ImageType>(std::string(av[imagenameindex]));
             }
           catch (itk::ExceptionObject &e)
             {
@@ -367,6 +201,7 @@ int itkNiftiImageIOTest(int ac, char* av[])
           std::cerr << "Error writing Nifti file type float" << std::endl;
           rval += cur_return;
         }
+#ifndef __BORLANDC__
       // awaiting a double precision byte swapper
       cur_return = MakeNiftiImage<double>();
       if(cur_return != 0)
@@ -375,6 +210,7 @@ int itkNiftiImageIOTest(int ac, char* av[])
           rval += cur_return;
         }
       rval += TestByteSwap();
+#endif
     }
   //Tests added to increase code coverage.
       {
@@ -400,7 +236,6 @@ int itkNiftiImageIOTest2(int ac, char* av[])
   int test_success = 0;
   typedef itk::Image<signed short, 3> ImageType ;
   typedef ImageType::Pointer ImagePointer ;
-  typedef itk::ImageFileReader< ImageType > ImageReaderType ;
 
   if((strcmp(arg1, "true") == 0) && WriteTestFiles() == -1)
     {
@@ -409,15 +244,17 @@ int itkNiftiImageIOTest2(int ac, char* av[])
 
 
 
-  itk::NiftiImageIO::Pointer io = itk::NiftiImageIO::New();
-  ImageReaderType::Pointer imageReader = ImageReaderType::New();
   ImagePointer input;
   try
     {
-      imageReader->SetImageIO(io);
-      imageReader->SetFileName(arg2);
-      imageReader->Update();
-      input = imageReader->GetOutput();
+    typedef itk::ImageFileReader<ImageType> ImageReaderType;
+    itk::NiftiImageIO::Pointer io = itk::NiftiImageIO::New();
+    ImageReaderType::Pointer imageReader = ImageReaderType::New();
+    imageReader->SetImageIO(io);
+    imageReader->SetFileName(arg2);
+    imageReader->Update();
+    input = imageReader->GetOutput();
+    input = ReadImage<ImageType>(std::string(arg2));
     }
   catch (itk::ExceptionObject &)
     {
@@ -435,16 +272,9 @@ int itkNiftiImageIOTest2(int ac, char* av[])
 
 }
 
-
-#include "itkRandomImageSource.h"
-#include <vnl/vnl_random.h>
-
-
-
-
 template <class ScalarType, unsigned VecLength, unsigned Dimension>
 int
-TestVectorImage()
+TestImageOfVectors(const std::string &fname)
 {
   const int dimsize = 2;
   /** Deformation field pixel type. */
@@ -453,20 +283,51 @@ TestVectorImage()
   /** Deformation field type. */
   typedef typename itk::Image<FieldPixelType,Dimension> VectorImageType;
 
-  /** file reader type */
-  typedef typename itk::ImageFileReader< VectorImageType >  FieldReaderType;
-
-  /** file writer type */
-  typedef typename itk::ImageFileWriter< VectorImageType >  FieldWriterType;
-
   //
   // swizzle up a random vector image.
-  typename VectorImageType::Pointer vi = VectorImageType::New();
+  typename VectorImageType::Pointer vi;
   typename VectorImageType::RegionType imageRegion;
   typename VectorImageType::SizeType size;
   typename VectorImageType::IndexType index;
   typename VectorImageType::SpacingType spacing;
   typename VectorImageType::PointType origin;
+  typename VectorImageType::DirectionType myDirection;
+  myDirection.Fill(0.0);
+  // original test case was destined for failure.  NIfTI always writes out 3D
+  // orientation.  The only sensible matrices you could pass in would be of the form
+  // A B C 0
+  // D E F 0
+  // E F G 0
+  // 0 0 0 1
+  // anything in the 4th dimension that didn't follow that form would just come up scrambled.
+  //NOTE: Nifti only reports upto 3D images correctly for direction cosigns.  It is implicitly assumed
+  //      that the direction for dimensions 4 or greater come diagonal elements including a 1 in the 
+  //      direction matrix.
+  switch(Dimension)
+    {
+    case 1:
+      myDirection[0][0] = -1.0;
+      break;
+    case 2:
+      myDirection[0][1] = 1.0;
+      myDirection[1][0] = -1.0;
+      break;
+    case 3:
+      myDirection[0][2] = 1.0;
+      myDirection[1][0] = -1.0;
+      myDirection[2][1] = 1.0;
+      break;
+    case 4:
+      myDirection[0][2] = 1.0;
+      myDirection[1][0] = -1.0;
+      myDirection[2][1] = 1.0;
+      myDirection[3][3] = 1.0;
+      break;
+    }
+  
+  std::cout << " === Testing VectorLength: " << VecLength << " Image Dimension " << static_cast<int>(Dimension) << std::endl;
+  std::cout << "======================== Initialized Direction" << std::endl;
+  std::cout << myDirection << std::endl;
 
   for(unsigned i = 0; i < Dimension; i++)
     {
@@ -478,16 +339,12 @@ TestVectorImage()
 
   imageRegion.SetSize(size); 
   imageRegion.SetIndex(index);
-  vi->SetRegions(imageRegion);
-  vi->SetSpacing(spacing);
+  AllocateImageFromRegionAndSpacing(VectorImageType, vi, imageRegion, spacing);
   vi->SetOrigin(origin);
-  vi->Allocate();
-
-  vnl_random randgen;
+  vi->SetDirection(myDirection);
 
   typedef itk::ImageRegionIterator<VectorImageType> IteratorType;
   typedef itk::ImageRegionConstIterator<VectorImageType> ConstIteratorType;
-  std::cout << "Original vector Image" << std::endl;
 
   int dims[7];
   int _index[7];
@@ -500,6 +357,7 @@ TestVectorImage()
     dims[i] = 1;
     }
 
+  int incr_value=0;
   //  for(fillIt.GoToBegin(); !fillIt.IsAtEnd(); ++fillIt)
   for(int l = 0; l < dims[6]; l++)
     {
@@ -526,7 +384,8 @@ TestVectorImage()
                 float lowrange(100.00),highrange(200.00);
                 for(unsigned int q = 0; q < VecLength; q++)
                   {
-                  pixel[q] = randgen.drand32(lowrange,highrange);
+                  //pixel[q] = randgen.drand32(lowrange,highrange);
+                  pixel[q] = incr_value++;
                   lowrange += 100.0;
                   highrange += 100.0;
                   }
@@ -535,7 +394,6 @@ TestVectorImage()
                   index[q] = _index[q];
                   }
                 vi->SetPixel(index,pixel);
-                std::cout << pixel << std::endl;
                 }
               }
             }
@@ -543,13 +401,9 @@ TestVectorImage()
         }
       }
     }
-  typename FieldWriterType::Pointer writer = FieldWriterType::New();
-  writer->SetInput(vi);
-  std::string fname("vectorImageTest.nii.gz");
-  writer->SetFileName(fname.c_str());
   try
     {
-    writer->Write();
+    WriteImage<VectorImageType>(vi,fname);
     }
   catch(itk::ExceptionObject &ex)
     {
@@ -564,12 +418,9 @@ TestVectorImage()
   //
   // read it back in.
   typename VectorImageType::Pointer readback;
-  typename FieldReaderType::Pointer reader = FieldReaderType::New();
   try
     {
-    reader->SetFileName(fname.c_str());
-    reader->Update();
-    readback = reader->GetOutput();
+    readback = ReadImage<VectorImageType>(fname);
     }
   catch(itk::ExceptionObject &ex)
     {
@@ -582,42 +433,29 @@ TestVectorImage()
     return EXIT_FAILURE;
     }
   bool same = true;
-  std::cout << "vector Image read from disk" << std::endl;
-  for(int l = 0; l < dims[6]; l++)
+  if(readback->GetOrigin() != vi->GetOrigin() )
     {
-    _index[6] = l;
-    for(int m = 0; m < dims[5]; m++)
+    std::cout << "Origin is different: " << readback->GetOrigin() << " != " << vi->GetOrigin()  << std::endl;
+    same = false;
+    }
+  if(readback->GetSpacing() != vi->GetSpacing() )
+    {
+    std::cout << "Spacing is different: " << readback->GetSpacing() << " != " << vi->GetSpacing()  << std::endl;
+    same = false;
+    }
+  for(unsigned int r=0;r<Dimension;r++)
+    {
+    for(unsigned int c=0;c<Dimension;c++)
       {
-      _index[5] = m;
-      for(int n = 0; n < dims[4]; n++)
+      if(vcl_abs(readback->GetDirection()[r][c] - vi->GetDirection()[r][c]) > 1e-7 )
         {
-        _index[4] = n;
-        for(int p = 0; p < dims[3]; p++)
-          { 
-          _index[3] = p;
-          for(int i = 0; i < dims[2]; i++)
-            {
-            _index[2] = i;
-            for(int j = 0; j < dims[1]; j++)
-              {
-              _index[1] = j;
-              for(int k = 0; k < dims[0]; k++)
-                {
-                _index[0] = k;
-                FieldPixelType pixel;
-                for(unsigned int q = 0; q < Dimension; q++)
-                  {
-                  index[q] = _index[q];
-                  }
-                pixel = readback->GetPixel(index);
-                std::cout << pixel << std::endl;
-                }
-              }
-            }
-          }
+        std::cout << "Direction is different:\n " << readback->GetDirection() << "\n != \n" << vi->GetDirection()  << std::endl;
+        same = false;
+        break;
         }
       }
     }
+  std::cout << "Original vector Image  ?=   vector Image read from disk " << std::endl;
   for(int l = 0; l < dims[6]; l++)
     {
     _index[6] = l;
@@ -649,6 +487,11 @@ TestVectorImage()
                 if(p1 != p2)
                   {
                   same = false;
+                  std::cout << p1 << " != " << p2 <<  "    ERROR! " << std::endl;
+                  }
+                else
+                  {
+                  std::cout << p1 << " == " << p2 << std::endl;
                   }
                 }
               }
@@ -657,7 +500,14 @@ TestVectorImage()
         }
       }
     }
-  Remove(fname.c_str());
+  if(same)
+    {
+    Remove(fname.c_str());
+    }
+  else
+    {
+    std::cout << "Failing image can be found at: " << fname << std::endl;
+    }
   return same ? 0 : EXIT_FAILURE;
 }
 /** Test writing and reading a Vector Image
@@ -676,14 +526,14 @@ int itkNiftiImageIOTest3(int ac, char* av[])
     return EXIT_FAILURE;
     }
   int success(0);
-  success |= TestVectorImage<float,3,1>();
-  success |= TestVectorImage<float,3,2>();
-  success |= TestVectorImage<float,3,3>();
-  success |= TestVectorImage<double,3,3>();
-  success |= TestVectorImage<float,4,3>();
-  success |= TestVectorImage<double,4,3>();
-  success |= TestVectorImage<float,4,4>();
-  success |= TestVectorImage<float,4,5>();
+  success |= TestImageOfVectors<float,3,1>(std::string("testVectorImage_float_3_1.nii.gz"));
+#ifndef __BORLANDC__
+  success |= TestImageOfVectors<float,3,2>(std::string("testVectorImage_float_3_2.nii.gz"));
+  success |= TestImageOfVectors<float,3,3>(std::string("testVectorImage_float_3_3.nii.gz"));
+  success |= TestImageOfVectors<float,4,3>(std::string("testVectorImage_float_4_3.nii.gz"));
+  success |= TestImageOfVectors<float,4,4>(std::string("testVectorImage_float_4_4.nii.gz"));
+  success |= TestImageOfVectors<double,3,3>(std::string("testVectorImage_double_3_3.nii.gz"));
+#endif
   return success;
 }
 
@@ -749,15 +599,12 @@ int itkNiftiImageIOTest4(int ac, char* av[])
     return EXIT_FAILURE;
     }
   
-  typedef itk::ImageFileWriter<Test4ImageType> Test4Writer;
-  typedef itk::ImageFileReader<Test4ImageType> Test4Reader;
   //
   Test4ImageType::Pointer test4Image = Test4ImageType::New();
   Test4ImageType::RegionType imageRegion;
   Test4ImageType::SizeType size;
   Test4ImageType::IndexType index;
   Test4ImageType::SpacingType spacing;
-  Test4ImageType::PointType origin;
   const unsigned dimsize = 2;
 
   for(unsigned i = 0; i < 3; i++)
@@ -765,16 +612,13 @@ int itkNiftiImageIOTest4(int ac, char* av[])
     size[i] = dimsize;
     index[i] = 0;
     spacing[i] = 1.0;
-    origin[i] = 0;
     }
 
   imageRegion.SetSize(size); 
   imageRegion.SetIndex(index);
-  test4Image->SetRegions(imageRegion);
-  test4Image->SetSpacing(spacing);
-  test4Image->SetOrigin(origin);
-  test4Image->Allocate();
+  AllocateImageFromRegionAndSpacing(Test4ImageType, test4Image, imageRegion, spacing);
   test4Image->FillBuffer(0);
+
   Test4ImageType::DirectionType dir;
   dir.SetIdentity();
 #if 1
@@ -805,13 +649,10 @@ int itkNiftiImageIOTest4(int ac, char* av[])
     itk::SpatialOrientationAdapter().ToDirectionCosines(itk::SpatialOrientation::ITK_COORDINATE_ORIENTATION_PLI);
 #endif
   test4Image->SetDirection(dir);
-  Test4Writer::Pointer writer = Test4Writer::New();
-  writer->SetInput(test4Image);
   std::string fname("directionsTest.nii.gz");
-  writer->SetFileName(fname.c_str());
   try
     {
-    writer->Write();
+    WriteImage<Test4ImageType>(test4Image,fname);
     }
   catch(itk::ExceptionObject &ex)
     {
@@ -826,12 +667,9 @@ int itkNiftiImageIOTest4(int ac, char* av[])
   //
   // read it back in.
   Test4ImageType::Pointer readback;
-  Test4Reader::Pointer reader = Test4Reader::New();
-  reader->SetFileName(fname.c_str());
   try
     {
-    reader->Update();
-    readback = reader->GetOutput();
+    readback = ReadImage<Test4ImageType>(fname);
     }
   catch(itk::ExceptionObject &ex)
     {
@@ -928,19 +766,16 @@ SlopeInterceptTest()
   //
   // read the image back in
   typedef typename itk::Image<float,3> ImageType;
-  typedef typename itk::ImageFileReader<ImageType> ReaderType;
-  typename ReaderType::Pointer reader = ReaderType::New();
-  reader->SetFileName(filename);
+  typename ImageType::Pointer image;
   try
     {
-    reader->Update();
+    image = ReadImage<ImageType>(std::string(filename));
     }
   catch(...)
     {
     Remove(filename);
     return EXIT_FAILURE;
     }
-  typename ImageType::Pointer image = reader->GetOutput();
   typedef typename itk::ImageRegionIterator<ImageType> IteratorType;
   IteratorType it(image,image->GetLargestPossibleRegion());
   it.GoToBegin();
@@ -967,6 +802,8 @@ SlopeInterceptTest()
   return maxerror > 0.00001 ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
+//
+// test vector images
 int itkNiftiImageIOTest5(int ac, char* av[])
 {
   //
@@ -988,3 +825,384 @@ int itkNiftiImageIOTest5(int ac, char* av[])
   success |= SlopeInterceptTest<unsigned int,NIFTI_TYPE_UINT32>();
   return success;
 }
+
+int itkNiftiImageIOTest6(int ac, char *av[])
+{
+  if(ac > 1) 
+    {
+    char *testdir = *++av;
+    itksys::SystemTools::ChangeDirectory(testdir);
+    }
+  else
+    {
+    return EXIT_FAILURE;
+    }
+  int success(EXIT_SUCCESS);
+
+  typedef itk::VectorImage<double,3> VectorImageType;
+  VectorImageType::RegionType imageRegion;
+  VectorImageType::SizeType size;
+  VectorImageType::IndexType index;
+  VectorImageType::SpacingType spacing;
+  VectorImageType::VectorLengthType vecLength(4);
+
+  for(unsigned i = 0; i < 3; i++)
+    {
+    size[i] = 3;
+    index[i] = 0;
+    spacing[i] = 1.0;
+    }
+  imageRegion.SetSize(size); imageRegion.SetIndex(index);
+  VectorImageType::Pointer vecImage;
+  AllocateVecImageFromRegionAndSpacing(VectorImageType, vecImage, imageRegion, spacing,vecLength);
+
+  itk::ImageRegionIterator<VectorImageType> 
+    it(vecImage,vecImage->GetLargestPossibleRegion());
+  double val(0.0);
+  for(it.GoToBegin(); it != it.End(); ++it)
+    {
+    VectorImageType::PixelType p(vecLength);
+    for(unsigned i = 0; i < vecLength; i++)
+      {
+      p[i] = val;
+      val++;
+      }
+    it.Set(p);
+    }
+  const std::string testfname("vectorImage.nii.gz");
+  VectorImageType::Pointer readback;
+  try
+    {
+    WriteImage<VectorImageType>(vecImage,testfname);
+    readback = ReadImage<VectorImageType>(testfname);
+    }
+  catch(itk::ExceptionObject &err)
+    {
+    std::cout << "itkNiftiImageIOTest6" << std::endl 
+              << "Exception Object caught: " << std::endl
+              << err << std::endl;
+    throw;
+    }
+  itk::ImageRegionIterator<VectorImageType>
+    readbackIt(readback,readback->GetLargestPossibleRegion());
+  for(it.GoToBegin(),readbackIt.GoToBegin();
+      it != it.End() && readbackIt != readbackIt.End();
+      ++it, ++readbackIt)
+    {
+    VectorImageType::PixelType p(vecLength),
+      readbackP(vecLength);
+    p = it.Get();
+    readbackP = readbackIt.Get();
+    if(p != readbackP)
+      {
+      std::cout << "Pixel mismatch at index "
+                << it.GetIndex()
+                << " original = "
+                << p
+                << " read value = "
+                << readbackP
+                << std::endl;
+      success = EXIT_FAILURE;
+      break;
+      }
+    }
+  Remove(testfname.c_str());
+  return success;
+}
+
+/* common code for DTi and sym matrix tests
+ *
+ * Could probably be made to fo the image of vector test as well
+ */
+
+template <class PixelType, unsigned Dimension>
+int
+TestImageOfSymMats(const std::string &fname)
+{
+
+  const int dimsize = 2;
+  /** Deformation field pixel type. */
+//  typedef typename itk::DiffusionTenor3D<ScalarType>    PixelType;
+
+  /** Deformation field type. */
+  typedef typename itk::Image<PixelType,Dimension>      DtiImageType;
+
+  //
+  // swizzle up a random vector image.
+  typename DtiImageType::Pointer vi;
+  typename DtiImageType::RegionType imageRegion;
+  typename DtiImageType::SizeType size;
+  typename DtiImageType::IndexType index;
+  typename DtiImageType::SpacingType spacing;
+  typename DtiImageType::PointType origin;
+  typename DtiImageType::DirectionType myDirection;
+  myDirection.Fill(0.0);
+  // original test case was destined for failure.  NIfTI always writes out 3D
+  // orientation.  The only sensible matrices you could pass in would be of the form
+  // A B C 0
+  // D E F 0
+  // E F G 0
+  // 0 0 0 1
+  // anything in the 4th dimension that didn't follow that form would just come up scrambled.
+  //NOTE: Nifti only reports upto 3D images correctly for direction cosigns.  It is implicitly assumed
+  //      that the direction for dimensions 4 or greater come diagonal elements including a 1 in the
+  //      direction matrix.
+  switch(Dimension)
+    {
+    case 1:
+      myDirection[0][0] = -1.0;
+      break;
+    case 2:
+      myDirection[0][1] = 1.0;
+      myDirection[1][0] = -1.0;
+      break;
+    case 3:
+      myDirection[0][2] = 1.0;
+      myDirection[1][0] = -1.0;
+      myDirection[2][1] = 1.0;
+      break;
+    case 4:
+      myDirection[0][2] = 1.0;
+      myDirection[1][0] = -1.0;
+      myDirection[2][1] = 1.0;
+      myDirection[3][3] = 1.0;
+      break;
+    }
+
+  std::cout << " === Testing DtiImageType:  Image Dimension " << static_cast<int>(Dimension) << std::endl;
+  std::cout << "======================== Initialized Direction" << std::endl;
+  std::cout << myDirection << std::endl;
+
+  for(unsigned i = 0; i < Dimension; i++)
+    {
+    size[i] = dimsize;
+    index[i] = 0;
+    spacing[i] = 1.0;
+    origin[i] = 0;
+    }
+
+  imageRegion.SetSize(size);
+  imageRegion.SetIndex(index);
+  AllocateImageFromRegionAndSpacing(DtiImageType, vi, imageRegion, spacing);
+  vi->SetOrigin(origin);
+  vi->SetDirection(myDirection);
+
+  typedef itk::ImageRegionIterator<DtiImageType> IteratorType;
+  typedef itk::ImageRegionConstIterator<DtiImageType> ConstIteratorType;
+
+  int dims[7];
+  int _index[7];
+  for(unsigned i = 0; i < Dimension; i++)
+    {
+    dims[i] = size[i];
+    }
+  for(unsigned i = Dimension; i < 7; i++)
+      {
+    dims[i] = 1;
+    }
+
+  int incr_value=0;
+  //  for(fillIt.GoToBegin(); !fillIt.IsAtEnd(); ++fillIt)
+  for(int l = 0; l < dims[6]; l++)
+    {
+    _index[6] = l;
+    for(int m = 0; m < dims[5]; m++)
+      {
+      _index[5] = m;
+      for(int n = 0; n < dims[4]; n++)
+        {
+        _index[4] = n;
+        for(int p = 0; p < dims[3]; p++)
+          {
+          _index[3] = p;
+          for(int i = 0; i < dims[2]; i++)
+            {
+            _index[2] = i;
+            for(int j = 0; j < dims[1]; j++)
+              {
+              _index[1] = j;
+              for(int k = 0; k < dims[0]; k++)
+                {
+                _index[0] = k;
+                PixelType pixel;
+                float lowrange(100.00),highrange(200.00);
+                for(unsigned int q = 0; q < pixel.Size(); q++)
+                  {
+                  //pixel[q] = randgen.drand32(lowrange,highrange);
+                  pixel[q] = incr_value++;
+                  lowrange += 100.0;
+                  highrange += 100.0;
+                  }
+                for(unsigned int q = 0; q < Dimension; q++)
+                  {
+                  index[q] = _index[q];
+                  }
+                vi->SetPixel(index,pixel);
+                }
+              }
+            }
+          }
+        }
+      }
+    }
+  try
+    {
+    WriteImage<DtiImageType>(vi,fname);
+    }
+  catch(itk::ExceptionObject &ex)
+    {
+    std::string message;
+    message = "Problem found while writing image ";
+    message += fname; message += "\n";
+    message += ex.GetLocation(); message += "\n";
+    message += ex.GetDescription(); std::cout << message << std::endl;
+    Remove(fname.c_str());
+    return EXIT_FAILURE;
+    }
+  //
+  // read it back in.
+  typename DtiImageType::Pointer readback;
+  try
+    {
+    readback = ReadImage<DtiImageType>(fname);
+    }
+  catch(itk::ExceptionObject &ex)
+      {
+    std::string message;
+    message = "Problem found while reading image ";
+    message += fname; message += "\n";
+    message += ex.GetLocation(); message += "\n";
+    message += ex.GetDescription(); std::cout << message << std::endl;
+    Remove(fname.c_str());
+    return EXIT_FAILURE;
+      }
+  bool same = true;
+  if(readback->GetOrigin() != vi->GetOrigin() )
+    {
+    std::cout << "Origin is different: " << readback->GetOrigin() << " != " << vi->GetOrigin()  << std::endl;
+    same = false;
+    }
+  if(readback->GetSpacing() != vi->GetSpacing() )
+    {
+    std::cout << "Spacing is different: " << readback->GetSpacing() << " != " << vi->GetSpacing()  << std::endl;
+    same = false;
+    }
+  for(unsigned int r=0;r<Dimension;r++)
+    {
+    for(unsigned int c=0;c<Dimension;c++)
+      {
+      if(vcl_abs(readback->GetDirection()[r][c] - vi->GetDirection()[r][c]) > 1e-7 )
+        {
+        std::cout << "Direction is different:\n " << readback->GetDirection() << "\n != \n" << vi->GetDirection()  << std::endl;
+        same = false;
+        break;
+      }
+    }
+    }
+  std::cout << "Original Image  ?=   Image read from disk " << std::endl;
+  for(int l = 0; l < dims[6]; l++)
+    {
+    _index[6] = l;
+    for(int m = 0; m < dims[5]; m++)
+      {
+      _index[5] = m;
+      for(int n = 0; n < dims[4]; n++)
+        {
+        _index[4] = n;
+        for(int p = 0; p < dims[3]; p++)
+          {
+          _index[3] = p;
+          for(int i = 0; i < dims[2]; i++)
+            {
+            _index[2] = i;
+            for(int j = 0; j < dims[1]; j++)
+              {
+              _index[1] = j;
+              for(int k = 0; k < dims[0]; k++)
+                {
+                _index[0] = k;
+                PixelType p1,p2;
+                for(unsigned int q = 0; q < Dimension; q++)
+                  {
+                  index[q] = _index[q];
+    }
+                p1 = vi->GetPixel(index);
+                p2 = readback->GetPixel(index);
+                if(p1 != p2)
+    {
+                  same = false;
+                  std::cout << p1 << " != " << p2 <<  "    ERROR! " << std::endl;
+    }
+                else
+    {
+                  std::cout << p1 << " == " << p2 << std::endl;
+                  }
+                }
+              }
+            }
+          }
+        }
+      }
+    }
+  if(same)
+      {
+    Remove(fname.c_str());
+      }
+  else
+    {
+    std::cout << "Failing image can be found at: " << fname << std::endl;
+    }
+  return same ? 0 : EXIT_FAILURE;
+}
+
+/** Test writing and reading a Vector Image
+ */
+int itkNiftiImageIOTest7(int ac, char* av[])
+{
+  //
+  // first argument is passing in the writable directory to do all testing
+  if(ac > 1)
+    {
+    char *testdir = *++av;
+    itksys::SystemTools::ChangeDirectory(testdir);
+    }
+  else
+    {
+    return EXIT_FAILURE;
+    }
+  int success(0);
+  success |= TestImageOfSymMats<itk::DiffusionTensor3D<float>,1>( std::string("testDtiImage_float_1.nii.gz"));
+  success |= TestImageOfSymMats<itk::DiffusionTensor3D<float>,2>( std::string("testDtiImage_float_2.nii.gz"));
+  success |= TestImageOfSymMats<itk::DiffusionTensor3D<float>,3>( std::string("testDtiImage_float_3.nii.gz"));
+  success |= TestImageOfSymMats<itk::DiffusionTensor3D<float>,4>( std::string("testDtiImage_float_4.nii.gz"));
+  success |= TestImageOfSymMats<itk::DiffusionTensor3D<double>,3>(std::string("testDtiImage_double_3.nii.gz"));
+  return success;
+}
+
+
+int itkNiftiImageIOTest8(int ac, char *av[])
+{
+  if(ac > 1) 
+    {
+    char *testdir = *++av;
+    itksys::SystemTools::ChangeDirectory(testdir);
+    }
+  else
+    {
+    return EXIT_FAILURE;
+    }
+  int success(0);
+
+  //only 3,4,5,6 as supported in itkImageIOBase
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,3>,1>(std::string("testSymImage_float_2_1.nii.gz"));
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,3>,2>(std::string("testSymImage_float_2_2.nii.gz"));
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,3>,3>(std::string("testSymImage_float_2_3.nii.gz"));
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,3>,4>(std::string("testSymImage_float_2_4.nii.gz"));
+
+//only test some of the others
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,4>,3>(std::string("testSymImage_float_3_3.nii.gz"));
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,5>,3>(std::string("testSymImage_float_3_3.nii.gz"));
+  success |= TestImageOfSymMats<itk::SymmetricSecondRankTensor<float,6>,3>(std::string("testSymImage_float_3_3.nii.gz"));
+
+  return success;
+}
