@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaUtils.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-24 19:13:40 $
-  Version:   $Revision: 1.55 $
+  Date:      $Date: 2009-07-08 15:54:08 $
+  Version:   $Revision: 1.58 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -16,6 +16,7 @@
 =========================================================================*/
 #ifdef _MSC_VER
 #pragma warning(disable:4702)
+#pragma warning(disable:4996)
 #endif
 
 #include "metaUtils.h"
@@ -709,6 +710,16 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
       count = buffer_size - z.avail_out;
       if ( count )
         {
+        // if we don't have enough allocation for the output buffer
+        // when the output is bigger than the input (true for small images)
+        if(j+count>=buffer_size) 
+          {
+          unsigned char* compressedDataTemp = new unsigned char[j+count+1];
+          memcpy(compressedDataTemp,compressedData,buffer_size);
+          delete [] compressedData;
+          compressedData = compressedDataTemp;
+          }
+        
         memcpy((char*)compressedData+j, (char *)output_buffer, count);
         }
       break;
@@ -718,6 +729,13 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
     count = buffer_size - z.avail_out;
     if ( count )
       {
+      if(j+count>=buffer_size) 
+        {
+        unsigned char* compressedDataTemp = new unsigned char[j+count+1];
+        memcpy(compressedDataTemp,compressedData,buffer_size);
+        delete [] compressedData;
+        compressedData = compressedDataTemp;
+        }
       memcpy((char*)compressedData+j, (char*)output_buffer, count);
       }
 
@@ -753,18 +771,26 @@ bool MET_PerformUncompression(const unsigned char * sourceCompressed,
   inflateInit(&d_stream);
   d_stream.next_in  = const_cast<unsigned char *>(sourceCompressed);
   d_stream.avail_in = sourceCompressedSize;
-
+  
   for (;;)
     {
     d_stream.next_out = (unsigned char *)uncompressedData;
     d_stream.avail_out = uncompressedDataSize;
     int err = inflate(&d_stream, Z_NO_FLUSH);
-    if((err == Z_STREAM_END))
+        
+    if((err == Z_STREAM_END)
+       || (err == Z_BUF_ERROR) // Sometimes inflate returns this non fatal.
+       )
       {
       break;
       }
+    else if(err < 0)
+      {
+      METAIO_STREAM::cerr << "Uncompress failed" << METAIO_STREAM::endl;
+      break;
+      }  
     }
-
+    
   inflateEnd(&d_stream);
 
   return true;
