@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmFile.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-05-14 12:25:32 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2009-04-29 21:40:53 $
+  Version:   $Revision: 1.28 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -525,6 +525,22 @@ bool File::GetSpacing(float &xspacing, float &yspacing, float &zspacing)
        }
      return true;
      }
+   else if( sopclassuid_used == "RT Dose Storage" )
+     {
+     // (3004,000c) DS [0.0\-2.5\-5.0\-7.5\-10.0\-12.5... # 132,23 GridFrameOffsetVector
+     DocEntry *p3 = GetDocEntry(0x3004,0x000c);
+     if( !p3 ) return false;
+     ContentEntry *entry2 = dynamic_cast<ContentEntry *>(p3);
+     std::string gridframeoffset = entry2->GetValue();
+     float z1, z2;
+     if ( sscanf( gridframeoffset.c_str(), "%f\\%f", &z1, &z2) != 2 )
+       {
+       zspacing = 1.;
+       return false;
+       }
+     zspacing = z2 - z1; // can be negative ...
+     return true;
+     }
 
   return false;
 }
@@ -1165,7 +1181,7 @@ bool File::IsMonochrome1()
 bool File::IsPaletteColor()
 {
    std::string PhotometricInterp = GetEntryValue( 0x0028, 0x0004 );
-   if (   PhotometricInterp == "PALETTE COLOR " )
+   if ( Util::DicomStringEqual(PhotometricInterp, "PALETTE COLOR") )
    {
       return true;
    }
@@ -1205,6 +1221,9 @@ bool File::IsYBRFull()
   */
 bool File::HasLUT()
 {
+   // Some SIEMENS MOSAIC have a RGB LUT but are declared as MONOCHROME2 ...
+   if( !IsPaletteColor() ) return false;
+
    // Check the presence of the LUT Descriptors, and LUT Tables    
    // LutDescriptorRed    
    if ( !GetDocEntry(0x0028,0x1101) )
@@ -1422,9 +1441,7 @@ int File::GetNumberOfScalarComponents()
       return 3;
    }
 
-   std::string strPhotometricInterpretation = GetEntryValue(0x0028,0x0004);
-
-   if ( Util::DicomStringEqual(strPhotometricInterpretation, "PALETTE COLOR") )
+   if( IsPaletteColor() )
    {
       if ( HasLUT() )// PALETTE COLOR is NOT enough
       {
@@ -1436,6 +1453,7 @@ int File::GetNumberOfScalarComponents()
       }
    }
 
+   std::string strPhotometricInterpretation = GetEntryValue( 0x0028, 0x0004 );
    // beware of trailing space at end of string      
    // DICOM tags are never of odd length
    if ( strPhotometricInterpretation == GDCM_UNFOUND   || 
