@@ -74,6 +74,43 @@ RegularExpression::RegularExpression (const RegularExpression& rxp) {
   this->regmlen = rxp.regmlen;                  // Copy remaining private data
 }
 
+// operator= -- Copies the given regular expression.
+RegularExpression& RegularExpression::operator= (const RegularExpression& rxp)
+{
+  if(this == &rxp)
+    {
+    return *this;
+    }
+  if ( !rxp.program )
+    {
+    this->program = 0;
+    return *this;
+    }
+  int ind;
+  this->progsize = rxp.progsize;                // Copy regular expression size
+  delete [] this->program;
+  this->program = new char[this->progsize];     // Allocate storage
+  for(ind=this->progsize; ind-- != 0;)          // Copy regular expresion
+    this->program[ind] = rxp.program[ind];
+  this->startp[0] = rxp.startp[0];              // Copy pointers into last
+  this->endp[0] = rxp.endp[0];                  // Successful "find" operation
+  this->regmust = rxp.regmust;                  // Copy field
+  if (rxp.regmust != 0) {
+    char* dum = rxp.program;
+    ind = 0;
+    while (dum != rxp.regmust) {
+      ++dum;
+      ++ind;
+    }
+    this->regmust = this->program + ind;
+  }
+  this->regstart = rxp.regstart;                // Copy starting index
+  this->reganch = rxp.reganch;                  // Copy remaining private data
+  this->regmlen = rxp.regmlen;                  // Copy remaining private data
+
+  return *this;
+}
+
 // operator== -- Returns true if two regular expressions have the same
 // compiled program for pattern matching.
 bool RegularExpression::operator== (const RegularExpression& rxp) const {
@@ -232,7 +269,7 @@ const unsigned char MAGIC = 0234;
  * Utility definitions.
  */
 
-#define UCHARAT(p)      ((const unsigned char*)(p))[0]
+#define UCHARAT(p)      (reinterpret_cast<const unsigned char*>(p))[0]
 
 
 #define FAIL(m) { regerror(m); return(0); }
@@ -279,7 +316,7 @@ static       char* regatom (int*);
 static       char* regnode (char);
 static const char* regnext (register const char*);
 static       char* regnext (register char*);
-static void        regc (unsigned char);
+static void        regc (char);
 static void        reginsert (char, char*);
 static void        regtail (char*, const char*);
 static void        regoptail (char*, const char*);
@@ -311,7 +348,7 @@ static int strcspn ();
 bool RegularExpression::compile (const char* exp) {
     register const char* scan;
     register const char* longest;
-    register unsigned long len;
+    register size_t len;
              int         flags;
 
     if (exp == 0) {
@@ -325,7 +362,7 @@ bool RegularExpression::compile (const char* exp) {
     regnpar = 1;
     regsize = 0L;
     regcode = &regdummy;
-    regc(MAGIC);
+    regc(static_cast<char>(MAGIC));
     if(!reg(0, &flags))
       {
         printf ("RegularExpression::compile(): Error in compile.\n");
@@ -357,7 +394,7 @@ bool RegularExpression::compile (const char* exp) {
     regparse = exp;
     regnpar = 1;
     regcode = this->program;
-    regc(MAGIC);
+    regc(static_cast<char>(MAGIC));
     reg(0, &flags);
 
     // Dig out information for optimizations.
@@ -389,7 +426,7 @@ bool RegularExpression::compile (const char* exp) {
             for (; scan != 0; scan = regnext(scan))
                 if (OP(scan) == EXACTLY && strlen(OPERAND(scan)) >= len) {
                     longest = OPERAND(scan);
-                    len = int(strlen(OPERAND(scan)));
+                    len = strlen(OPERAND(scan));
                 }
             this->regmust = longest;
             this->regmlen = len;
@@ -638,7 +675,7 @@ static char* regatom (int *flagp) {
                                return 0;
                             }
                             for (; rxpclass <= rxpclassend; rxpclass++)
-                                regc(static_cast<unsigned char>(rxpclass));
+                              regc(static_cast<char>(rxpclass));
                             regparse++;
                         }
                     }
@@ -741,7 +778,7 @@ static char* regnode (char op) {
 /*
  - regc - emit (if appropriate) a byte of code
  */
-static void regc (unsigned char b) {
+static void regc (char b) {
     if (regcode != &regdummy)
         *regcode++ = b;
     else
@@ -981,14 +1018,14 @@ static int regmatch (const char* prog) {
                 reginput++;
                 break;
             case EXACTLY:{
-                    register int         len;
+                    register size_t len;
                     register const char* opnd;
 
                     opnd = OPERAND(scan);
                     // Inline the first character, for speed.
                     if (*opnd != *reginput)
                         return (0);
-                    len = int(strlen(opnd));
+                    len = strlen(opnd);
                     if (len > 1 && strncmp(opnd, reginput, len) != 0)
                         return (0);
                     reginput += len;
@@ -1197,7 +1234,6 @@ static const char* regnext (register const char* p) {
         return (p + offset);
 }
 
-
 static char* regnext (register char* p) {
     register int offset;
 
